%-------------------------------------------------------------------------
% Routine     : nusim.m      
%
% Description : Optimization of number of elements in annular array. The
%		optimization gives the minimum number of elements.
%
% Language    : Matlab 4.1
% Written by  : Espen Iveland (IBT)
%
% Version no. : 1.0 EI 29.06.93   
% 		1.5 EI 01.12.93 Some changes in output format.
%             : 2.0 FT 23.02.94 Removed disp('EXIT = "x"')
%
% Called by   : usimcnf
% Calling     : nusimtxt
%------------------------------------------------------------------------

function[transducer,elem_pts]=nusim(transducer,flagg,excitation,media);

if flagg(2)==3 & transducer(18)==0

b=0.523;                                       % constant (1dB)

fid=1;
lambda=media(1,2)/excitation(1);
if length(flagg)>4
  if flagg(5)==1
    lambda_local=1;
  elseif flagg(5)==2
    lambda_local=media(1,2)/excitation(1)*1e3;
  end
else
  lambda_local=1;
end

transducer(4)=transducer(1);


com1=0;
while com1~='x'
  clc

  nusimtxt;
  
  disp('	CHANGE 		= "number"')
  com1 = input('-> Decision (<CR> = exit): ','s');
  if isempty(com1) com1 = 'x'; end
  
  
  % changing of parameters
  
  if com1=='4'
    temp=input('Max transducer diameter 	Dmax = ');
    if ~isempty(temp) transducer(4)=temp*lambda_local*1e-3; end
  elseif com1=='5'
    temp=input('F-near 				Fn = ');
    if ~isempty(temp) transducer(5)=temp*lambda_local*1e-3; end
  elseif com1=='6'
    temp=input('F-far				Ff = ');
    if ~isempty(temp) transducer(6)=temp*lambda_local*1e-3; end
 end
 
end 					%while
transducer(9)=(2*transducer(5)*transducer(6))/(transducer(5)+transducer(6));
temp=(transducer(4)^2*((transducer(9)/transducer(5))-1))/(4*transducer(9)*lambda*b);
transducer(2)=fix(temp);
transducer(1)=2*sqrt((transducer(9)*transducer(2)*lambda*b)/((transducer(9)/transducer(5))-1));

fprintf('\n');
fprintf('Fixed focus \t\t\t F \t = %7.2f mm = %7.2f lambda\n',transducer(9)*1e3,transducer(9)/lambda);
fprintf('Minimum number of elements \t N \t = %4.0f  \n',transducer(2));
fprintf('Transducer aperture \t\t D \t = %7.2f mm = %7.2f lambda\n',transducer(1)*1e3,transducer(1)/lambda);
fprintf('\n');


[elem_pts] = annular(transducer, excitation, media);


else
   disp('')
   disp('Optimization of other than equal area annular array is not implemented!')
end;





