function [fangle,ienergy] = intenerg(plotfig,excitation,observasjon,energy,option,flagg);

%------------------------------------------------------------------------
% Routine         : intenerg.m
%
% Description     : Integrates the 2-way energy-response from angle x 
%		    (x=minangle:maxangle) to maxangle and divides by the
%		    square of the total transmitted energy. 
%		    Plots the results. 
%
% Limitations     : The energy must be calculated before calling the routine
%		    (preferably from 0 to 90 degrees). The observasjon-
%		    variable must correspond to the variable used when
%		    calculating the energy. The observation must be along
%		    a line, with phi(p) as variable and fixed r and theta(h).
%
% Language        : Matlab 4.1
% Written by      : Frode Teigen, IBT  
%
% Version no.     : 1.0 FT 02.09.93 First Version
%                   1.5 FT 21.09.94 Corrected angle step
%
% Called by       : usimcnf
% Routines called : 
% ----------------------------------------------------------------
 		
%          INFORMATION
%------------------------------------------------------------------------
disp(' ******************Integration of Sidelobe Energy*****************')
disp('                            intenerg.m ')
disp('  ')
disp(' Program for finding the total energy of the sidelobes, by integrating') 
disp(' the calculated energy from all angles to the maximum angle (90 degrees)')
disp(' ');
disp(' NB! The observation configuration must be identical to the one used when ')
disp(' calculating the energy. ')
disp(' ');

%          DEFINITION OF PARAMETERS
%------------------------------------------------------------------------
%
if flagg(4) == 1 | flagg(4) == 3
  %
  %convert from rectangular coordinates
  %
  [ElF_r, ElF_theta, ElF_phi] = xyz2rhp(excitation(2),excitation(3),excitation(4));
end
startang = observasjon(3);
stopang = observasjon(7);
stepang = observasjon(9);
energy = 10.^(energy/10);

if (option(1) == '1')   % Observation must be a line
 
  if (flagg(4) == 1)     
    disp('Line in rectangular coordinates not tested!')
    return
  elseif option(2)~='p'
    disp('phi must be chosen as observation axis');
    return
  else
%          INTERPOLATING TO 1001 points.
%------------------------------------------------------------------------
%
  angl = startang:(stopang-startang)/(stepang - 1):stopang;
  fangle = startang:(stopang-startang)/1000:stopang;
  fenergy = interp1(angl,energy,fangle,'spline');

%          FINDING TOTAL TRANSMITTED ENERGY
%------------------------------------------------------------------------
%
  totenergy = sin(fangle(1001))*fenergy(1001);
  for ind = 1000:-1:1,
	totenergy = totenergy + sin(fangle(ind))*fenergy(ind);
  end

%          INTEGRATING RECIEVED 2-WAY ENERGY
%------------------------------------------------------------------------
%
  ienergy = zeros(1,1001);
  ienergy(1001) = sin(fangle(1001))*fenergy(1001)^2/totenergy^2;
  for ind = 1000:-1:1,
 	ienergy(ind) = sin(fangle(ind))*fenergy(ind)^2/totenergy^2 + ienergy(ind+1);
  end

%          PLOTTING
%------------------------------------------------------------------------
%
  figure(plotfig);
 
  fangle = fangle*180/pi;
  ienergy=20*log10(ienergy);

% Selects different linetypes if several plots are drawn in
% the same figure by using hold on.
%-----------------------------------------------------------------

currentline = get(line,'LineStyle');
hol=get(gca,'NextPlot');
if (hol(1)=='a')  	% hold on
   if length(currentline) == 1
	if (currentline == '-')
   		set(gca,'DefaultLineLineStyle','--');
	else
   		set(gca,'DefaultLineLineStyle','-');
	end
   else
	if (currentline == '--')
   		set(gca,'DefaultLineLineStyle','-.');
	else
   		set(gca,'DefaultLineLineStyle',':');
 	end
   end
else
   set(gca,'DefaultLineLineStyle','-');
end
  plot(fangle,ienergy,get(line,'Linestyle'));
  title('Total Sidelobe Energy    2-Way Response');
  grid on;
   xlabel([ quanttxt(excitation),', ', num2str(abstxt(option,observasjon))]);
   ylabel(['[dB], ',focustxt(ElF_r),', steered angles = (',num2str((180/pi)*ElF_phi),', ',num2str((180/pi)*ElF_theta),') degrees']);
   axis('normal');

  end

else
  disp('Observations other than along a line is not implemented!')
  return 
end
