%------------------------------------------------------------------------
% Routine         : quantize
%
% Description     : quantize the time delays to accuracy qt 
%		    (only if interpolation is off)
%
% Language        : MATLAB 4.0
% Written by      : Sverre Holm
%
% Version no.     : 3.0
% Version no.     : 3.1 SH  26.03.93 
% Version no.     : 3.2 VEB 22.04.93
% Version no.     : 3.3 TKL 30.07.93 Changed some names, new heading
%
% Called by       : bpusim, beampat
%------------------------------------------------------------------------

function [quant]=quantize(excitation,exact)

%
% initialize
%
   Fs=excitation(11);
   f=excitation(1);
   intfact=excitation(12);
   N=length(exact);

%
% quantize the time delays to accuracy qt (only if interpolation is off)
%
   if (intfact==1)
     format long 
     disp(['Quantizing time delays to accuracy ',num2str(1e9/(intfact*Fs)),' ns'])
    

%
% For theta(p,2):
%

%    delay_add = 0          % gives symmetric quantization error
     delay_add = 0.24999    % gives worst case (max positive bias)

% 
% For theta(p,3):
%
%    delay_add = +/- .1666666 gives symmetric quantization error
%

     format 
     intt=exact.*(intfact*Fs)+delay_add ;
     quant = (round(intt)-delay_add)/(intfact*Fs);
   else

     disp('No quantization of beamformer time delays');
     quant = exact;

   end
	
	









