function [y] = userpuls(el_pts,xx,pvect,plen,attenuation)

%------------------------------------------------------------------------
% Routine     : userpuls.m
%
% Description : M-file for computing pulse value by looking up the value
%		in the vector, pvect, representing the excited pulse.
%		The matrix xx contains the time at which a pulse arrives
%		to each of the observation points from each of the trans-
%		ducer points. In version 2.0 the pulses may be set 
%		induvidually for each transducer element, making pvect
%		a matrix where the row number corresponds to the trans-
%		ducer element number. Also changed from ver. 1.0 is the
%		fact that the times found in matrix xx, now is relative 
%		to the start of the pulse instead of the middle as in v1.0.
%
% Language    : Matlab 4.0
% Written by  : Frode Teigen, IBT.
%
% Version no. : 1.0 FT 01.08.93 First Version
%	        2.0 FT 06.01.94 
%	        3.0 FT 28.09.94 Included attenuation
%               3.1 LO 14.12.95 flagg removed from call 
%
% Called by       : beampat
% Calling   :  
%------------------------------------------------------------------------
%

	[m,n] = size(xx);
	x = xx(:);

       if max(size(attenuation))>1
	  a = attenuation(:);
	else
	  a = ones(size(x))*attenuation;
	end
	y = zeros(size(x));

if min(size(pvect))==1    %same pulse on all transducer elements
%
%  check for pulse on or off
%
   pmin = 0;
   pmax = plen;
   i = find(x>=pmin & x<=pmax);
%
%  find 

   y(i) = pvect(round(x(i)/plen*1000) + 1).*a(i)';

else			%individual pulses on transducer elements
   N = max(el_pts(4,:));
   for f = 1:N

	% find index to all el. in matrix xx which is related to trans-
	% ducer element f.
	%
	ind = find(el_pts(4,:)==f);
	ind = ones(m,1)*ind;
	ind = (ind-1)*m;
	add = (1:m)';
	ind = ind + add*ones(1,size(ind,2));
	ind = ind(:);
%
%  check for pulse on or off
%
   	pmin = 0;
   	pmax = plen(f);
   	i = find(x(ind)>=pmin & x(ind)<=pmax);
%
%  find 
  	 y(ind(i)) = pvect(f,round(x(ind(i))/plen(f)*1000) + 1).*(a(i));
   end  % for
end     % if

y = reshape(y,m,n);
return


