%------------------------------------------------------------------------ 
% Routine     : coartool.m 
% Description : The coarray tools                    
%  
% Language    : Matlab 4.1 
% Written by  : Jan Ove Erstad , IfI-UiO 
% 
% Version no. : 1.0 JOE 20.10.94 First version 
%               1.1 SH  23.11.94 Changed condition for apodization flag 
%               1.2 JOE 31.03.95 Routine's menu calls are changed 
%               1.3 BJE 25.04.95 removed ConfigOrigHandle, from function call
%
% Called by   : usimcnf 
% Calling     : cocomp, coplot 
%------------------------------------------------------------------------ 
function coarray = coartool(coarray,elem_pts,transducer,option,media,... 
      excitation,flagg,config,plotfig,plotfigOrigHandle); 
  
  figure(plotfig); 
  done  = 0; 
  apoaz = excitation(5); 
  apoel = excitation(6); 
  coerror = []; 
  ctype = 1; 
  if apoaz >= 1 & apoaz <= 4 
      aptxt = '*ON*'; 
      exita = 1; 
    else 
      aptxt = ' OFF'; 
      exita = 0; 
  end  
  while ~done 
      clc 
      disp(' '); 
      disp('------------ COARRAY TOOLS MENU ------------------ '); 
      disp('| Calculate difference coarray         :   1     |'); 
      disp('| Calculate sum coarray                :   2     |'); 
      disp('| Plot coarray lag-values              :   3     |'); 
      disp('| Beampattern from linear coarray      :   4     |'); 
      disp('| Beampattern from linear error coarray:   5     |'); 
      disp('| Beampatt. of coarray + error coarray :   6     |'); 
      disp('| Optional coarray plot for 2D array   :   7     |'); 
      disp('|                                                |'); 
      disp(['| Apodization  is                      :  ',aptxt,'   |']); 
      disp('| Toggle apodization ON/OFF            :   0     |'); 
      disp('| Push a number larger than 7 to quit!           |'); 
      disp('--------------------------------------------------'); 
      disp('Please set toggle OFF if not existing apodization vector!'); 
      disp(' '); 
      btn = input('Choose function : '); 
      if isempty(btn) 
          disp('Try again! '); 
        else 
          if btn == 1 			%difference coarray 
              ctype = 1; 
              [coarray,coerror] = cocomp(exita,ctype,transducer,option,flagg,... 
                  elem_pts,excitation,config); 
% 
            elseif btn == 2 			% sum coarray 
              ctype = 2;  
              [coarray,coerror] = cocomp(exita,ctype,transducer,option,flagg,... 
                  elem_pts,excitation,config); 
% 
            elseif btn == 3 		%plot lag values 
              if ~isempty(coarray), 
                  PlotOpt = 0; 
                  coplot(coarray,coerror,ctype,elem_pts,transducer,option,... 
                      media,excitation,flagg,plotfig,plotfigOrigHandle,PlotOpt); 
                else 
                  disp('No coarray has been calculated!'); 
                  input('Push a key to continue.'); 
              end 	 
% 
            elseif btn == 4 			%beampattern linear array 
              if ~isempty(coarray), 
                  PlotOpt = 1; 
                  coplot(coarray,coerror,ctype,elem_pts,transducer,option,... 
                      media,excitation,flagg,plotfig,plotfigOrigHandle,PlotOpt); 
                else 
                  disp('No coarray has been calculated!'); 
                  input('Push a key to continue.'); 
              end 	 
% 
            elseif btn == 5 			%beampattern of error coarray 
              if ~isempty(coerror), 
                  PlotOpt = 2; 
                  coplot(coarray,coerror,ctype,elem_pts,transducer,option,... 
                      media,excitation,flagg,plotfig,plotfigOrigHandle,PlotOpt); 
                else 
                  disp('Error coarray is empty or has not been calculated!'); 
                  input('Push a key to continue.'); 
              end 	 
% 
%sum of beampatterns from coarray and error coarray 
            elseif btn == 6 			 
              if (~isempty(coerror)) & (~isempty(coarray)), 
                  PlotOpt = 3; 
                  coplot(coarray,coerror,ctype,elem_pts,transducer,option,... 
                      media,excitation,flagg,plotfig,plotfigOrigHandle,PlotOpt); 
                else 
                  disp('Error coarray and coarray must be calculated first!'); 
                  input('Push a key to continue.'); 
              end 	 
% 
            elseif btn == 7 			%optional 2D plot 
              if all(coarray(2,:) == 0), 
                  disp('This is a linear (1D) coarray!.'); 
                  input('Push a key to continue.'); 
                else 
                  PlotOpt = 1; 
                  coplot(coarray,coerror,ctype,elem_pts,transducer,option,... 
                      media,excitation,flagg,plotfig,plotfigOrigHandle,PlotOpt); 
              end  
            elseif btn == 0 
              if exita 
                  exita = 0; 
                  aptxt = ' OFF'; 
                else 
                  exita = 1; 
                  aptxt = '*ON*'; 
              end  
              disp('Apodization toggled.'); 
          end  					%if btn == 
          if  (~any(btn == [0 1 2 3 4 5 6 7]))   
              done = 1; 
          end  
      end  					% else (~isempty) 
  end  					%while ~done 
  fprintf('\n\nFinished! -> returning to Ultrasim.\n');
%------------------------------------------------------------------------ 
  
