%------------------------------------------------------------------------ 
% Routine     : cocomp.m 
% Description : Routine for computing the coarray for a given planar  
%		array. The baseline-approach.                    
% 
% Language    : Matlab 4.1 
% Written by  : Jan Ove Erstad , IfI-UiO 
% 
% Version no. : 1.0  JOE 10.02.94, First version 
%		1.1  JOE 24.02.94, Rewritten , fewer operations 
%		1.2  JOE 19.04.94  Changed variables and included apodizing 
%		1.4  JOE 26.04.94  Included Error-coarray calculation 
%		1.5  JOE 16.08.94  Corrected sum coarray element 
%		1.6  JOE 20.09.94  Some corrections and changed function call 
%		1.7  JOE 18.03.95  Calculation changed, routine simplified  
%		1.8  BJE 25.04.95  removed ConfigOrigHandle from functioncall
%
%
% Called by   : coartool 
% Calling     : apod,apodtxt 
%------------------------------------------------------------------------ 
function [coarray,coerr] = cocomp(exita,CType,transducer,option,... 
      flagg,elem_pts,excitation,config); 
% 
% Coarray matrix elements: 
% ------------------------------- 
% coarray(1,:) <-> x coordinates  
% coarray(2,:) <-> y coordinates  
% coarray(3,:) <-> lag value      
% ------------------------------- 
% 
  fid   = 1; 
  TElem= elem_pts; 			% Put element points in a local matrix 
  N     = length(TElem(1,:)); 		% number of elements in uniform array 
  thinn = find(TElem(4,:) <= 0); 	% find thinned and non-thinned elements 
  nonth = find(TElem(4,:) > 0); 
  if thinn 
      elem_pts(4,thinn) = -1*elem_pts(4,thinn); 
  end  
  
  max_points = transducer(2)*transducer(6); 
  pitch = transducer(1)/transducer(2); 
  
  if (N > max_points) & (flagg(2) ==1), 
      disp('ERROR: Too many points per element in rectangular transducer'); 
      return 
  end  
% 
  clc 
  disp(' '); 
  disp('************** COARRAY CALCULATION ROUTINE ************** '); 
  disp('Please note!  z-coordinates are not used in the calculations!!'); 
  
% ********************** 
% Calculate apodization  
% ********************** 
  if (flagg(2) == 1), 			% rectangular array 
      if (exita == 1) & any([1 2 3 4] == excitation(5)), 
          shading = apod(transducer, excitation, elem_pts, flagg); 
          shadefu = shading; 
          shading(thinn) = zeros(1,length(thinn)); 
          
        elseif exita == 0 
          excitation(5) = 0; 
          shading = apod(transducer, excitation, elem_pts, flagg); 
          shadefu = shading; 
          shading(thinn) = zeros(1,length(thinn)); 
      end  
% 
    else 					%shading non rectangular array 
      excitation(5) = 6; 
      shading = ones(1,N); 
  end  					%if flagg(2)==1 
% 
  if all(TElem(2,:) == 0) & (flagg(2) == 1), 
      atxt = apodtxt(excitation(5)); 
      disp([atxt,' apodization included.']); 
    elseif (flagg(2) == 1) 
      [atxt,etxt] = apodtxt(excit,excitation(6)); 
      disp([atxt,' apodization included (azimuth).']); 
      disp([etxt,' apodization included (elevation).']); 
  end  
% 
% 
  disp(' '); 
  disp('WAIT!  CALCULATING VALUES FOR THE COARRAY-ELEMENTS.'); 
  fprintf(fid,'%4.0f loops-->',N); 
% 
  if CType == 1 
% 
%=========================================== 
%----------- DIFFERENCE COARRAY ------------ 
%=========================================== 
% 
%---- Initialization ---- 
      Nno  = length(nonth); 
      Nth  = length(thinn); 
      Md  = Nno*(Nno-1)+1; 
      Mdd = N*(N-1)+1;  
      
%	memory for the coarray  
      coarray = zeros(3,Md); 
%Vectors used during calculations 
% 
      diffc = zeros(3,Nno); 
      equal = 0;   count1=1;  
% 
%---- Calculation part ---- 
% 
      for k=1:N 
          
          if (N > 10), 
              fprintf(fid,'.',N); 
          end  
          
          if (TElem(4,k) > 0) , 
              diffc= [TElem(1,k)-TElem(1,nonth); TElem(2,k)-TElem(2,nonth);... 
                  shading(k)*shading(nonth)];  
% Compare vectorsums/-differences and put them into an array 
              for l=1:Nno 
                  m=1;  
% 
%Checking difference coarray 
% 
                  while (m <= count1) & ~equal, 
                      
                      if (abs(diffc(1,l) - coarray(1,m)) < eps), 
                          if (abs(diffc(2,l) - coarray(2,m)) < eps),  
                              coarray(3,m) = coarray(3,m) + diffc(3,l); 
                              equal = 1; 
                            else  
                              m = m+1; 
                          end  			%if(abs(diffc(2,l)  
                          
                        else 
                          m = m+1; 
                      end  				%if(abs(diffc(1	 
                      
                  end  				%while (m <=count1 
% 
%include new element in difference coarray 
% 
                  if m > count1  
                      count1 = count1 +1; 
                      coarray(:,count1) = diffc(:,l); 
                  end  				% if m > count1 
                  equal = 0; 
              end  				%for l=1:Nno 
          end  				%if (TElem(4,k)  
      end  					%outer calculation loop 
% 
%---- Number of elements in the coarray ---- 
% 
      disp(' '); 
      disp(['Max. no. of distinct elements in the difference coarray :',num2str(Md)]) 
      disp(['For this transducer there are ',num2str(count1),... 
          ' distinct elements in the coarray.']); 
      RedDeg = Md/count1; 
      disp(['Degree of redundancy  :  ',num2str(RedDeg) ]); 
% 
    elseif (CType == 2) 
% 
%================================	 
%--------- SUM COARRAY ---------- 
%================================ 
      
% --- Initialization --- 
      Nno  = length(nonth); 
      Nth  = length(thinn); 
      Ms  = Nno*(Nno+1)/2; 			% max number for this sum coarray 
      Mss = N*(N+1)/2; 			% max number for filled array 
      
      
      coarray  = zeros(3,Ms); 		%memory for sum coarray 
      sumc  = zeros(3,Nno); 		% Vectors used during the calculation 
      equal = 0;  count1 = 1;  
% 
%--- Calculation part ---- 
% 
      for k=1:N 
          
          if (N > 10), 
              fprintf(fid,'.',N); 
          end  
          
          if (TElem(4,k) > 0) , 
              
              sumc = [TElem(1,k)+TElem(1,nonth);... 
                  TElem(2,k)+TElem(2,nonth);... 
                  shading(k)*shading(nonth)]; 
              
% Compare vectorsums/-differences and put them into an array 
              for l=1:Nno 
                  n=1; 
% 
%Checking sum coarray 
% 
                  while (n <= count1) & ~equal, 
                      
                      if (abs(sumc(1,l) - coarray(1,n)) < eps), 
                          if (abs(sumc(2,l) - coarray(2,n)) < eps),   
                              coarray(3,n) = coarray(3,n) + sumc(3,l); 
                              equal = 1; 
                            else 
                              n=n+1; 
                          end  			%if (abs(sumc(2,l) 
                        else 
                          n=n+1; 
                      end  				%if (abs(sumc(1, 
                  end  				%while(n <= count1 
% 
%include new element in sumcoarray 
% 
                  if n > count1  
                      count1 	= count1 + 1; 
                      coarray(:,count1) = sumc(:,l); 
                  end  				% if n > count1 
                  equal = 0; 
                  
              end  				%for l=1:Ne 
          end  				%if TElem(4 
          
      end  					%for k=1:N (outer loop) 
% 
%---- Number of elements in the coarray ---- 
% 
      disp(' '); 
      disp(['Max. no. of distinct elements in the sum coarray :',num2str(Ms)]); 
      colent	=  length(coarray(3,coarray(3,:) ~= 0)); 
      disp(['For this transducer there are ',num2str(colent),... 
          ' elements in the coarray.']); 
      RedDeg = Ms/colent; 
      disp(['Degree of redundancy   :  ',num2str(RedDeg) ]); 
      disp(' '); 
  end  					%if Ctype == 
  
% 
%Throw away elements equal to zero 
% 
  coarray = coarray(:,coarray(3,:) ~= 0); 
  [cc,index] = sort(coarray(1,:)); 
  coarray = coarray(:,index); 
  if ((excitation(5) ~= 4) & all(TElem(2,:) == 0)), 
      refrnce  = conv(shadefu,shadefu); 
% refrnce will have a size different from coarray if coarray has missing lags, 
% thus we must fill in the missing zero values 
      cnmbr	= max(size(coarray)); 
      rlent	= max(size(refrnce)); 
      msnglms = rlent - cnmbr; 
      if (msnglms) 
          coarray(:,rlent) = zeros(3,1); 
          coarray(:,rlent) = coarray(:,cnmbr); 
          l = 1; 
          for k=rlent-1:-1:2 
              if (k == cnmbr - l) 
                  break 
              end  
              xpos  = coarray(1,k+1) - pitch; 
              if (xpos - coarray(1,cnmbr-l) < eps) 
                  coarray(:,k) = coarray(:,cnmbr-l); 
                  l  = l + 1; 
                else 
                  coarray(:,k) = [xpos; 0; 0]; 
              end  
          end  
      end  			%if(msnglms) 
      coerr    = refrnce - coarray(3,:);  
% Plot coarray if it exists 
      if ~any(coerr(:) > 0) 
          disp('There is no error coarray in this case.'); 
          coerr = []; 
      end  
    elseif ((excitation(5) == 4) & any(TElem(2,:) ~= 0)) 
      disp('The coarray can only be compared to an ideal '); 
      disp('when applying conventional apodization.'); 
      disp(' '); 
      coerr = []; 
    else 
      disp('No error coarray is calculated.'); 
      coerr = []; 
  end 				%if excitation(5) ~= 
  disp(' '); 
  disp('FINISHED!'); 
  disp(' '); 
  input('Push a key to continue! '); 
%------------------------------------------------------------------ 
  
