%------------------------------------------------------------------------  
% Routine     : coplot.m  
% Description : Plotting the coarrays in Ultrasim-plot window    
%  
% Language    : Matlab 4.1  
% Written by  : Jan Ove Erstad , IfI  
%  
% Version no. : 1.0 JOE 10.02.94 First version  
%               1.1 JOE 23.02.94 Rewritten  
%               1.2 JOE  7.03.94 Including lag value.  
%               1.3 JOE 19.04.94 Changed variables, include lag value and   
%                                and matrix for Error-coarray  
%               1.4 JOE 24.05.94 Included plotting options and text corrected  
%               1.5 JOE 22.07.94 Corrected axes for FFT of coarray  
%               1.6 JOE 16.08.94 Enabled call for optional plots  
%               1.7 JOE 14.09.94 Scaling axes included  
%               1.8 JOE 20.10.94 Some extensions and new function call  
%               1.9 JOE 01.04.95 Removed and/or rewritten some plot options 
%
% Called by   : coartool  
% Calling     : none  
%------------------------------------------------------------------------  
function coplot(coray,coerr,Ctype,elem_pts,transducer,option,...
      media,excitation,flagg,plotfig,plotfigOrigHandle,PlotOpt);  
  
  fid=1;  
  disp(' ');  
  figure(plotfig);  
  Nry  = length(find(elem_pts(4,:) > 0)); 	% number of elements in array  
  Nco	  = length(find(coray(3,:) > 0));	% number of elements in coarray  
  pitch = transducer(1)/transducer(2);  
  lambda = media(1,2)/excitation(1);  
  nonmsng = find(coray(3,:) ~= 0);  
%  
%Choosing which coarray to plot  
%  
  if Ctype == 1,  
      co_type = 'DIFFERENCE ';  
      RedDeg  =  (Nry*(Nry - 1)+ 1)/Nco;  
    elseif Ctype == 2,  
      co_type = 'SUM ';  
      RedDeg  =  (Nry*(Nry + 1))/(2*Nco);	  
  end  
  
  coarray = [1000*coray(1:2,:); coray(3,:)];  
  disp(' ');   
  
  if all(coarray(2,:) == 0),  
      if (PlotOpt == 0),  
          cleanscr(plotfig,plotfigOrigHandle);  
%	==================================================  
%	Plotting the coarray for a LINEAR transducer array  
%	==================================================  
%	  
%	the spatial dimension of the coarray  
          co_dim    = [max(coarray(1,:))-min(coarray(1,:))];   
% distance between elements (when array is linear AND regular)  
% Info texts  
          disp(['Plotting ',co_type,' coarray for a linear array.']);  
          disp(' ');  
          disp(['There are ',num2str(Nco),' elements in the coarray.']);  
          fprintf(fid,['Linear dimension  \t\t',num2str(co_dim),' [mm]\n']);  
          fprintf(fid,['Interelement distance \t\t',num2str(1000*pitch),...  
              ' [mm]\t',num2str(pitch/lambda),' [lambda]\n']);  
          fprintf(fid,['Degree of redundancy:  \t\t',num2str(RedDeg),'\n']);  
          mu     = sum(coarray(1,:).*coarray(3,:))/max(size(coarray));  
          sigma2 = sum(((coarray(1,:)-mu).^2).*coarray(3,:)/max(coarray(3,:)));  
          sd=std(coarray(3,:));  
          fprintf(fid,['Coarray variance: \t',num2str(sd^2),'\n']);  
          smplc   	= coarray(1,:).*coarray(3,:);  
          avgc 	= std(smplc)^4;  
          gammac 	= sum(smplc.^4)/avgc - 3 ; % Formula from Larsen&Marx  
          fprintf(fid,['(Quasi)Coarray kurtosis: \t',num2str(gammac),'\n']);  
          
% Plot 'conventional' coarray  
          subplot(2,1,1);  
          plot(coarray(1,:),coarray(3,:),'g.');  
          xlabel('Lag [mm]');  
          ylabel('Coarray value');  
          hand=get(gca,'child');  
          set(hand(1),'Markersize',12);  
          title([co_type,' COARRAY ']);  
          axs	=   [1.1*min(min(coarray(1,:)),-max(coarray(1,:))) ...  
              1.1*max(max(coarray(1,:)),-min(coarray(1,:))) ...  
              min(min(coarray(3,:)),0) 1.05*max(coarray(3,:))];  
          axis(axs);  
          grid on 
          
% Plotting error coarray  
          if ~isempty(coerr)  
              disp(' ');  
              disp([co_type,' error coarray ']);  
              
%the error coarray's spatial dimension '  
              coer_dim = [max(coarray(1,:))-min(coarray(1,:))];  
              disp(['There are ',num2str(max(size(coerr))),...  
                  ' elements in the error coarray. ']);  
              fprintf(fid,['Linear dimension  \t\t',num2str(coer_dim),' [mm]\n']);  
% the error coarray's mean value  '  
              mu = mean(coerr);  
              fprintf(fid,['Mean value error coarray: \t',num2str(mu),'\n']);  
              
% Plot error coarray  
              subplot(2,1,2);  
              plot(coarray(1,:),coerr,'c.');  
              title([co_type,'ERROR COARRAY ']);  
              xlabel('Lag-length [mm]');  
              ylabel('Error value ');  
              hand=get(gca,'child');  
              set(hand(1),'Markersize',12);  
              axis(axs);  
              grid on  
            else   
              disp('Error coarray does not exist!');  
          end 				%if ~isempty(coerr)  
      end 					%if PlotOpt == 0,  
%	    
      
% Calculate and plot beampattern from the coarray 
      if (PlotOpt == 1) |  (PlotOpt == 3),  
          dela   = pi/512;  
          phi    = -pi/2:dela:pi/2;  
          Nangls = max(size(phi));  
          wvnum  = 2*pi/lambda;  
          angl   = 180/pi*phi;  
          coa    = coray;  
          for k = 1:Nangls  
              zeta = j*wvnum*sin(phi(k));  
              Cbp(k) = sum(coa(3,:).*exp(zeta*coa(1,:)));  
          end  
          
          if (PlotOpt ~= 3), 
              subplot(1,1,1);  
              Cphi   = abs(Cbp)./abs(max(Cbp));  
              plot(angl,10*log10(Cphi)); grid on  
              title('Beampattern from coarray');  
              xlabel('Azimuth angle [Deg]');  
              ylabel('Response [dB]');  
              lowr = max(-105, min(10*log10(Cphi))); 
              axis([-90 90 lowr 0]) 
          end 
      end 				%if PlotOpt == 1,  
      
% Calculate and plot beampattern from the coarray 
      if (PlotOpt == 2) |  (PlotOpt == 3),  
          dela   = pi/512;  
          phi    = -pi/2:dela:pi/2;  
          Nangls = max(size(phi));  
          wvnum  = 2*pi/lambda;  
          angl   = 180/pi*phi;  
          ercoa  = coerr;  
          for k = 1:Nangls  
              zeta = j*wvnum*sin(phi(k));  
              Cerbp(k) = sum(ercoa.*exp(zeta*coray(1,:)));  
          end  
          
          if (PlotOpt ~= 3), 
              subplot(1,1,1);  
              Cerrbp   = abs(Cerbp)./abs(max(Cerbp));  
              plot(angl,10*log10(Cerrbp)); grid on  
              title('Beampattern from coarray');  
              xlabel('Azimuth angle [Deg]');  
              ylabel('Response [dB]');  
              lowr = max(-80, min(10*log10(Cerrbp))); 
              axis([-90 90 lowr 0]) 
          end 
      end  
      
% Plot the sum of the coarray and the error coarray beampattern 
      if (PlotOpt == 3), 
          subplot(1,1,1); 
          sumBP = Cbp + Cerbp; 
          sumBP = abs(sumBP)./abs(max(sumBP));  
          plot(angl,10*log10(sumBP)); grid on  
          title('Beampattern from coarray and error coarray');  
          xlabel('Azimuth angle [Deg]');  
          ylabel('Response [dB]');  
          lowr = max(-105, min(10*log10(sumBP))); 
          axis([-90 90 lowr 0]) 
      end 
      else	  
%	======================================================  
%	Plotting coarray for two dimensional transducer arrays  
%	======================================================  
%	  
      subplot(1,1,1);  
%   
      if PlotOpt == 0,  
          subplot(1,1,1);  
%  
% Finding equal valued lags  
%   
          M =length(coarray); l =1;  
          val(1) = max(coarray(3,:));  
          plo = find(coarray(3,:) == val);  
          plot(coarray(1,plo),coarray(2,plo),'y.');  
          hold on  
%  
          Nn = length(plo);  
          rest = M - Nn;  
          k = 1;  
%   
          while rest > 0,  
              plo = find(coarray(3,k) == coarray(3,:));  
              if ~any(val == coarray(3,k))  
                  l = l+1;  
                  val(l) = coarray(3,k);  
                  plot(coarray(1,plo),coarray(2,plo),'y.');  
                  Nn = Nn + length(plo);  
                  rest = M - Nn;  
              end 				%if ~any  
              k = k+1;  
          end 				%while  
          disp(' ');  
          disp(['Plotting ',co_type,' COARRAY']);  
          hand=get(gca,'child');  
          L = length(hand);  
% set object size  
          for l=L:-1:1,  
              lag_val = 10 + 10*log(val(L-l+1));  
              set(hand(l),'Markersize',lag_val);  
          end  
%  
          title([co_type,' coarray (values indicated by size).']);  
          xlabel('x  [mm]');  
          ylabel('y  [mm]');  
          axis([ 1.2*min(coarray(1,:)) 1.2*max(coarray(1,:)) ...  
              1.2*min(coarray(2,:)) 1.2*max(coarray(2,:)) ])  
          hold off  
        else 					%OPTIONAL PLOTS   
          disp('Plot points in 3D.');  
          plot3(coarray(1,:),coarray(2,:),coarray(3,:),'g*');  
          title('Coarray lag values');  
          
%	surf(coarray(1,:),coarray(2,:),coarray(3,:),'g');  
%      disp('Not implemented yet!');  
      end 					%if PlotOpt == 1  
  end 					%if all(coarray(2,:)==0)  
  disp(' ');  
  input('Push a key to continue! ');  
% ------------------------------------------------------------------  
  
