% -----------------------------------------------------------------------------
% Function    : [elem_pts]=centelem(centers,elem_pts)
%
% Description : An array which has been thinned by toggling sign
%               of centers(4,:) need also to have elem_pts(4,:) toggled
%               for the same elements
%
%
% Language    : Matlab 4.2
% Written by  : Sverre Holm, Ifi-UiO
%
% Version no. : 1.0  SH  20.11.96 First version
%               1.1  AA  03.07.97 Restoring of elem_pts before translation.  
%               1.2  SH  10.09.97 Speeded up by copying if equal size
%
% Called by   : thinning.m
% Calling     : none
% --------------------------
function [elem_pts]=centelem(centers,elem_pts);

% Restoring elem_pts, AA 03.07.97
elem_pts(4,:) = abs(elem_pts(4,:)); 

%
% translate from centers to elem_pts
%
N = length(centers);
N2 = length(elem_pts);

if N==N2,
  elem_pts = centers;
else

  for nn = 1:N;
    if centers(4,nn) < 0,
      az = -centers(4,nn);
      el = centers(5,nn);
      ind = (elem_pts(4,:) == az & elem_pts(5,:) == el);
      elem_pts(4,ind) = -elem_pts(4,ind);
    end
  end
end
