%------------------------------------------------------------------------------
% Routine	      : initelem.m
% Description	      : Partitioning the array-elements into subelements,
%			calculating some constants, initializing some variables
% Language	      : MATLAB
% Written by	      : Vebjorn Berre
% Version no.	      : 3.0
% Date		      : 9/10-92
% Revised	      : 7/1-93 by VEB
% Called by	      : apusim
% Routines called     :	fasestyr,fasefors
% Input variables     : P,Q,a,b,lambda,maxfeil,FASEST,APP
% Variables defined   : rho,c,k,Z,f,da,db,pc,qc,R,S,das,dbr,ps,qr,x1s,x2r,x3r
%			x1p,x2q,x3q,FASEFEIL,FASE,ei2x,ei2tab,METODE
% Variables initialized : H,p,ux,uy,uz
%------------------------------------------------------------------------------

function elem_pts=initelem(transducer,transducerflagg);

if transducerflagg==1

a=transducer(1);
P=transducer(2);
R=transducer(3);

b=transducer(5);
Q=transducer(6);
S=transducer(7);

F=transducer(9);

	%nr. paa midtelementet 
pc=(P+1)/2;
qc=(Q+1)/2;
	%dimensjonene av elementene
da=a/P;
db=b/Q;
	%nr. paa midterste subelement
ps=(P*S+1)/2;
qr=(Q*R+1)/2;
	%dimensjonene av subelementene
dbr=b/(Q*R);
das=a/(P*S);

[Pm,Qm]=meshdom([1:1:P],[1:1:Q]);
Qm=flipud(Qm);
x1p=(Pm-pc)*da;
x2q=(Qm-qc)*db;
if F==Inf x3q=zeros(x1p); if isempty(x3q) x3q=0; end, else
x3q=F-sqrt(F^2-x2q.^2); end

[PSm,QRm]=meshdom([1:1:P*S],[1:1:Q*R]);
QRm=flipud(QRm);
x1s=(PSm-ps)*das;
x2r=(QRm-qr)*dbr;
if F==Inf x3r=zeros(size(x1s)); if isempty(x3r) x3r=0;end, else
x3r=F-sqrt(F^2-x2r.^2); end

elem_pts(1,:)=reshape(x1s,1,P*Q*R*S);
elem_pts(2,:)=reshape(x2r,1,P*Q*R*S);
elem_pts(3,:)=reshape(x3r,1,P*Q*R*S);

else
	elem_pts=[];
end

