%------------------------------------------------------------------------
% Routine         : musim.m
%
% Description     : Configuring medium-parameters
%
% Language        : Matlab 4.1
% Written by      : Vebjorn Berre, IBT
% Version no.     : 2.0 VEB 27.10.92 First Version
% Version no.     : 3.0 VEB 17.02.93
% Version no.     : 3.1 FT  27.09.93 Added 3D-layered media [flagg(3)=3]
% Version no.     : 3.2 FT  06.01.94 Added call to partxt & functxt
%                                    Values converted to mm before displaying
%                 : 3.3 FT  19.01.94 Unabled changes to z of layer 1
%                 : 3.4 FT  02.02.94 Added function class 5
%                   3.5 FT  23.02.94 Removed disp('EXIT = "x"')
%                   3.6 FT  22.03.94 Tests if z>0 for layered media
%                   3.7 FT  28.09.94 Added attenuation (3D media)
%                   3.8 EH  27.11.95 Added new surface (3D media)
%                   3.9 EH  22.12.95 Changed input param. for 3D media
%                   4.0 EH  19.02.96 Implemented class 7 in 3D media
%                   4.1 LO  02.10.96 Small correction of output positions
%
% Called by       : usimcnf
% Routines called : str2int, mediatxt, modeltxt, partxt, functxt
%------------------------------------------------------------------------

function [media,flagg] = musim(media,transducer,excitation,flagg)
fid=1;
no = length(media(:,1)) + 1;
% just to show some other parameters
if flagg(3)==2
  media(1,3)=3;
  media(1,4)=transducer(15);
  media(1,5)=transducer(9);
  media(1,6)=transducer(10);
  media(1,7)=transducer(1);
else
  media(1,[3 4 5 6 7])=[0 0 0 0 0];
end
tmpsize=size(media);
if tmpsize(2)<11
  tmp=media;
  media=zeros([tmpsize(1),11]);
  media([1:tmpsize(1)],[1:tmpsize(2)])=tmp;
end
% media submenu
com1=0;
while com1~='x'
  clc

  musimtxt;

  if flagg(3)==1
    disp('      EDIT            = "1-4"')
  elseif flagg(3)==2 | flagg(3)==3
    % disp('    VIEW               = "v"')
    disp('      EDIT               = "e ( + #)"')
    disp('      DELETE             = "d"')
    disp('      CREATE new layer   = "c"')
    if flagg(3)==3
      disp(['      Toggle ',num2str(no),'), ',num2str(no+1),...
	      ') or ',num2str(no+2),')= Number']);
    end
  end

  com1 = input('-> Decision (<CR> = exit): ','s');
  if isempty(com1) com1 = 'x'; end
  % CHANGING of PARAMETERS
  %------------------------------------------------------
  if com1(1)=='1' & flagg(3)==1
    temp=input(' Speed of Sound (m/s)   =  ');
    if ~isempty(temp) media(1,2)=temp; end
  elseif com1=='2' & flagg(3)==1
    temp=input('Impedance Z [MRayl] = ');
    if ~isempty(temp) media(1,8)=temp*1e6; end
  elseif com1=='3' & flagg(3)==1
    temp=input('Attenuation - alpha = ');
    if ~isempty(temp) media(1,9)=temp; end
  elseif com1=='4' & flagg(3)==1
    temp=input('Attenuation - beta = ');
    if ~isempty(temp) media(1,10)=temp; end
  %------------------------------------------------------
  elseif com1(1)=='d' & (flagg(3)==2 | flagg(3)==3)
    n=input('DELETE layer # : ');
    if ~isempty(n) & n<=length(media(:,1))
      ind=(1:length(media(:,1)));
      ind=find(ind~=n);
      media=media(ind,:);
    end
 elseif com1(1)=='c' & (flagg(3)==2 | flagg(3)==3)
   temp=input('Depth z = [mm] ');
   if isempty(temp) | temp<=0
     disp(' Error! z must be greater than 0. ');
     disp(' Press any key to continue...');
     pause;
   else
     media=[media;temp*1e-3 1540 1 0 0 0 0 0 0 0 0];
   end
 elseif flagg(3)==3 & com1==int2str(no)
   if fix(flagg(6)/2)~=flagg(6)/2
     flagg(6) = flagg(6) - 1;
   else
     flagg(6) = flagg(6) + 1;
   end
 elseif flagg(3)==3 & com1==int2str(no+1)
   if fix(flagg(6)/4)~=flagg(6)/4 & fix((flagg(6)-1)/4)~=(flagg(6)-1)/4
     flagg(6) = flagg(6) - 2;
   else
     flagg(6) = flagg(6) + 2;
   end
 elseif flagg(3)==3 & com1==int2str(no+2)
   if fix(flagg(6)/4)
     flagg(6) = flagg(6) - 4;
   else
     flagg(6) = flagg(6) + 4;
   end
 elseif com1(1)=='e' & (flagg(3)==2 | flagg(3)==3)
   n=str2int(com1([2:1:length(com1)]));
   if n<1 | n>length(media(:,1))
     temp=input('EDIT layer # : ');n=temp;
   end
   if ~isempty(n) & n>=1 & n<=length(media(:,1))
     temp2=menu35('EDIT','z (depth)','c','Z - impedance','alpha - attenuation','beta - attenuation','function class','parameters a-e');

     if n==1 & (temp2>5) & temp2<8
	disp(' NOT allowed to change this parameter from this menu')
	disp(' Parameter is set in transducer-configuration menu');
	dummy = input(' Press <enter> to continue','s');
     elseif n==1 & temp2==1
	disp(' NOT allowed to change this parameter')
	dummy = input(' Press <enter> to continue','s');
     else
       if temp2==2
	 temp=menu35([' Speed of Sound   c_', num2str(n),' = '],'bone c=3000 ','fat c=1440','muscle c=1580','gel c=1540','fluid in the transduce c=1574','transducerdome c=1880','other')
	 if isempty(temp) media(n,2)=3000;
	 elseif temp==1 media(n,2)=3000;
	 elseif temp==2 media(n,2)=1440;
	 elseif temp==3 media(n,2)=1580;
	 elseif temp==4 media(n,2)=1540;
	 elseif temp==5 media(n,2)=1574;
	 elseif temp==6 media(n,2)=1880;
	 elseif temp==7 media(n,2)=input(' Speed of Sound (m/s) =  '); if isempty(media(n,2)) media(n,2)=1540; end
	 end
       elseif temp2==1
	 temp=input('Depth z = [mm] ');
	 if ~isempty(temp) & temp>0
	   media(n,1)=temp*1e-3;
	 else
	   disp(' Error! z must be greater than 0. ');
	   disp(' Press any key to continue...');
	   pause;
	 end
       elseif temp2==3
	 temp=input('Impedance Z [MRayl] = ');
	 if ~isempty(temp) media(n,9)=temp*1e6; end
       elseif temp2==4
	 temp=input('Attenuation - alpha = ');
	 if ~isempty(temp) media(n,10)=temp; end
       elseif temp2==5
	 temp=input('Attenuation - beta = ');
	 if ~isempty(temp) media(n,11)=temp; end
       elseif temp2==6
	 if n==1
		dummy = input('Choose antenna parameters for changes - push <enter> to continue','s');
	 else
	   if flagg(3)==2
	      temp=menu35('Function class ',mediatxt(flagg,1),...
			mediatxt(flagg,2),[mediatxt(flagg,3),...
			' (layer #1 only)'],mediatxt(flagg,4),...
			mediatxt(flagg,5));
	      if ~isempty(temp) & find(temp==[1 2 4 5])
		media(n,3) = temp;
	      end
	   elseif flagg(3)==3
	      temp=menu35('Function class ',...
			mediatxt(flagg,1),mediatxt(flagg,2),...
			mediatxt(flagg,6),mediatxt(flagg,7));
	      if ~isempty(temp) & find(temp==[1 2 3 4])
		if temp  <= 2
		   media(n,3) = temp;
		else
		   media(n,3) = 3+temp;
		end
	      end
	   end
	 end
       elseif temp2==7
	 if n==1 disp('Choose antenna parameters for changes - push any key to continue'), pause;
	 else
	   if flagg(3)==2
	     if media(n,3)==1
		for nn = 1:3
		   media(n,4+nn) = media(n,4+nn)/10^(3*nn);
		end
	     elseif media(n,3)==2
		media(n,[4 5 7]) = media(n,[4 5 7])*1e3;
	     elseif media(n,3)==4
		media(n,[4 5 6]) = media(n,[4 5 6])*1e3;
	     end
	     media(n,[4 5 6 7])=changes(['Change ',...
		mediatxt(flagg,media(n,3)),' parameters'],...
		functxt(flagg,media(n,3)),partxt(media(n,3),flagg,'a'),...
		partxt(media(n,3),flagg,'b'),partxt(media(n,3),flagg,'c'),...
		partxt(media(n,3),flagg,'d'),media(n,[4 5 6 7]));
	     if media(n,3)==1
		for nn = 1:3
		   media(n,4+nn) = media(n,4+nn)*10^(3*nn);
		end
	     elseif media(n,3)==2
		media(n,[4 5 7]) = media(n,[4 5 7])/1e3;
	     elseif media(n,3)==4
		media(n,[4 5 6]) = media(n,[4 5 6])/1e3;
	     end

	   elseif flagg(3)==3
	     if media(n,3)==1
		media(n,[5 7]) = media(n,[5 7])/1e3;
	     elseif media(n,3)==2
		media(n,[4 5 6 8]) = media(n,[4 5 6 8])*1e3;
	     elseif media(n,3) == 6
		media(n,[5 6]) = media(n,[5 6 ])*1e3;
	     elseif media(n,3) == 7
		media(n,[4 5 8]) = media(n,[4 5 8])*1e3;
	     end
	     media(n,[4 5 6 7 8])=changes(['Change ',...
		mediatxt(flagg,media(n,3)),' parameters'],...
		functxt(flagg,media(n,3)),...
		partxt(media(n,3),flagg,'a'),partxt(media(n,3),flagg,'b'),...
		partxt(media(n,3),flagg,'c'),partxt(media(n,3),flagg,'d'),...
		partxt(media(n,3),flagg,'e'),media(n,[4 5 6 7 8]));
	     if media(n,3)==1
		media(n,[5 7]) = media(n,[5 7])*1e3;
	     elseif media(n,3)==2
		media(n,[4 5 6 8]) = media(n,[4 5 6 8])/1e3;
	     elseif media(n,3) == 6
		media(n,[5 6]) = media(n,[5 6])/1e3;
	     elseif media(n,3) == 7
		media(n,[4 5 8]) = media(n,[4 5 8])/1e3;
	     end
	   end
	 end
       end
     end
   end
   % elseif com1=='v'
   % figure(viewfig);
   % viewprob(media,flagg,option,transducer,excitation,x,z)
 end

 [Y,I]=sort(media(:,1));
 media=media(I,:);
end                                     %while
