%------------------------------------------------------------------------
% Routine         : t1usimtx
%
% Description     : Configuring transducer-parameters - update window
%			 CURVED AND RECTANGULAR ARRAY
% Language        : Matlab 5.0
% Written by      : Vebjorn Berre 12/5-93
% Version no.     : 1.0
% Version no.     : 1.1 TKL 14.07.93 Replaced the lambda_local printout
% Version no.     : 1.2 SH  10.09.93 Changed format for output of transducer type
%                   1.3 SH   2.12.93 Corrected line for elevation # points
%                   1.4 SH  25.02.94 2D array
%                   1.5 FT  20.03.94 Changed text 1.5D + kerf->comment
%                   1.6 SH   6.12.94 Shortened from t1usimtxt to t1usimtx
%                   1.7 SH   9. 1.95 Added output of curved array parameters
%                   1.8 SH  16.03.95 Simplified label of menu
%                   1.9 SH  11.05.95 Included decimals in format for transducer(18) 
%                   2.0 SH  15.07.96 split 1.5 d setup to t1u15dtx.m
%                   2.1 SH  15.05.97 Improved output of arc-length
%                   2.2 SH  22.05.97 Toggling of mm/lambda in transducer menu 
%                   3.0 JEK 30.06.00 Adapted to GUI
%                   
% Called by       : t1usim
% Routines called : none
%------------------------------------------------------------------------

function t1usimtx(transducer, lambda)

% set(findobj('Tag','InputText'),'String',['lambda = ',num2str(lambda*1e3)],' mm');

% display transducershape
set(findobj('Tag','ShapeEdit'),'String',transducer(18));
if transducer(18) == 0 set(findobj('Tag','ShapeMenu'),'Value',1);
elseif transducer(18) == 2 set(findobj('Tag','ShapeMenu'),'Value',2);
elseif transducer(18) == 2.5 set(findobj('Tag','ShapeMenu'),'Value',3);
elseif transducer(18) == -8 set(findobj('Tag','ShapeMenu'),'Value',4);
elseif transducer(18) == -2 set(findobj('Tag','ShapeMenu'),'Value',5);
elseif transducer(18) == -1 set(findobj('Tag','ShapeMenu'),'Value',6);
else set(findobj('Tag','ShapeMenu'),'Value',7);
end

set(findobj('Tag','ROCmm'),'String',transducer(17)*1e3);
set(findobj('Tag','ROClambda'),'String',transducer(17)/lambda);

curved = transducer(17) ~= 0 & finite(transducer(17));  

set(findobj('Tag','dmm'),'String',transducer(1)*1e3);
set(findobj('Tag','dlambda'),'String',transducer(1)/lambda);   

if curved
   set(findobj('Tag','dText'),'String','Azimuth array-aperture (chord)');
   ROC = abs(transducer(17));
   arc = ROC*2*asin(transducer(1)/(2*ROC));
   set(findobj('Tag','carcmm'),'String',arc*1e3);
   set(findobj('Tag','carclambda'),'String',arc/lambda);
   set(findobj('Tag','cang'),'String',180*arc/(pi*ROC));
   CE = 'on';
   BgC = [1 1 1];
else
   set(findobj('Tag','dText'),'String','Azimuth array-aperture');
   set(findobj('Tag','carcmm'),'String',0);
   set(findobj('Tag','carclambda'),'String',0);
   set(findobj('Tag','cang'),'String',0);   
   CE = 'inactive';
   BgC = [0.6 0.6 0.6];
end

% set angles
set(findobj('Tag','carcmm'),'Enable',CE,'BackgroundColor',BgC);
set(findobj('Tag','carclambda'),'Enable',CE,'BackgroundColor', BgC);
set(findobj('Tag','cang'),'Enable',CE,'BackgroundColor',BgC)

% set azimuth elements and points
set(findobj('Tag','Ne_az'),'String',transducer(2));
set(findobj('Tag','Np_az'),'String',transducer(3));

% if not 1.5-D
if (transducer(6)~=3 & transducer(6)~=5)
   if transducer(6) == 1
      set(findobj('Tag','ElText'),'String','ELEVATION (1-D)');
   else
      set(findobj('Tag','ElText'),'String','ELEVATION (2-D)');
   end
   set(findobj('Tag','aimoMenu'),'String',{''})
   set(findobj('Tag','rimoMenu'),'String',{''})
   set(findobj('Tag','omoMenu'),'String',{''})
   set(findobj('Tag','aimomm'),'String','0');
   set(findobj('Tag','aimolambda'),'String','0');
   set(findobj('Tag','rimomm'),'String',transducer(9)*1e3);
   set(findobj('Tag','rimolambda'),'String',transducer(9)/lambda);
   set(findobj('Tag','omomm'),'String','0');
   set(findobj('Tag','omolambda'),'String','0');
   ME = 'inactive';
   BgC = [0.6 0.6 0.6];
else % if 1.5-D
   ME = 'on';
   BgC = [1 1 1];
end

set(findobj('Tag','aimomm'),'Enable',ME,'BackgroundColor',BgC);
set(findobj('Tag','aimolambda'),'Enable',ME,'BackgroundColor',BgC);
set(findobj('Tag','omomm'),'Enable',ME,'BackgroundColor',BgC);
set(findobj('Tag','omolambda'),'Enable',ME,'BackgroundColor',BgC);

set(findobj('Tag','amm'),'String',transducer(5)*1e3);
set(findobj('Tag','alambda'),'String',transducer(5)/lambda);
set(findobj('Tag','Me_el'),'String',transducer(6));
set(findobj('Tag','Mp_el'),'String',transducer(7));