function [transducer,elem_pts,centers]=t1usim(transducer,flagg,excitation,media)
%------------------------------------------------------------------------
% Routine         : t1usim       
%
% Description     : Configuring transducer-parameters
%                   1 1/2D CURVED RECTANGULAR ARRAY
%
% Language        : Matlab 4.1
% Written by      : Vebjorn Berre, IBT
%
% Version no.     : 1.0 VEB 27.10.92 First Version
%                 : 2.0 SH  30.03.93
%                   3.0 FT  23.02.94 Removed disp('EXIT = "x"')
%                   3.1 FT  20.03.94 kerf->comments + check if choise is
%                                    legal
%                   3.2 SH   6.12.94 Changed calls: rectangular to rectangu
%                                                   t1usimtxt   to t1usimtx
%                   3.3 SH   9. 1.95 Added input of curved array parameters
%                 : 3.4 KE   2.05.96 '??' at transducer type gives a list of
%                                    options (i.e. transducer types)
%                   3.5 SH   8. 5.96 Slight modification of user interface
%                   3.6 SH  21.05.96 Changed test of input for xdcr shape
%                   3.7 SH  03.06.96 centers as output
%                   3.8 SH  15.07.96 split transducer(10:16) to t1us15d.m
%                   3.9 SH  22.05.97 Toggling of mm/lambda in transducer menu
%						  4.0 JEK 06.07.00 Implemented GUI for MATLAB 5.0
%
% Called by       : usimcnf
% Routines called : t1usimgui
%------------------------------------------------------------------------

load t1usim

elem_pts = 0;
centers = 0;

% normalize from 800x600-screen to any other
screen = get(0, 'ScreenSize');
XSize = screen(3)/800;
YSize = screen(4)/600;
PosChange = [XSize YSize XSize YSize];
FontName = get(0,'factoryuicontrolfontname');
FontSize = floor(10*YSize);

h0 = figure('Color',[0.8 0.8 0.8], ...
	'Colormap',mat0, ...
	'FileName','C:\MATLABR11\toolbox\ultrasim\user\t1usim.m', ...
	'Name','ULTRASIM - TRANSDUCER SUBMENU', ...
	'NumberTitle','off', ...
	'PaperPosition',[18 180 576 432].*PosChange, ...
	'PaperUnits','points', ...
	'Position',[75 50 610 425].*PosChange, ...
	'Tag','Fig1', ...
	'ToolBar','none');
h1 = uicontrol('Parent',h0, ...
	'Units','points', ...
	'BackgroundColor',[0.6 0.6 0.6], ...
	'FontName',FontName, ...
	'FontSize',FontSize, ...
	'ListboxTop',0, ...
	'Position',[100 293 250 12].*PosChange, ...
	'String','TRANSDUCER SUBMENU', ...
	'Style','text', ...
	'Tag','HeaderText1');
h1 = uicontrol('Parent',h0, ...
	'Units','points', ...
	'BackgroundColor',[0.6 0.6 0.6], ...
	'FontName',FontName, ...
	'FontSize',FontSize, ...
	'ListboxTop',0, ...
	'Position',[100 280 250 12].*PosChange, ...
	'String','RECTANGULAR AND CURVED ARRAY', ...
	'Style','text', ...
	'Tag','HeaderText2');
h1 = uicontrol('Parent',h0, ...
	'Units','points', ...
	'BackgroundColor',[0.8 0.8 0.8], ...
	'FontName',FontName, ...
	'FontSize',FontSize, ...
	'ListboxTop',0, ...
	'Position',[20 10 300 12].*PosChange, ...
	'String','Message', ...
	'Style','text', ...
	'Tag','MessageText');
h1 = uicontrol('Parent',h0, ...
	'Units','points', ...
	'BackgroundColor',[0.8 0.8 0.8], ...
	'FontName',FontName, ...
	'FontSize',FontSize, ...
	'HorizontalAlignment','left', ...
	'ListboxTop',0, ...
	'Position',[20 30 160 12].*PosChange, ...
	'String','Elevation offset,', ...
	'Style','text', ...
	'Tag','omoText');
h1 = uicontrol('Parent',h0, ...
	'Units','points', ...
	'BackgroundColor',[0.8 0.8 0.8], ...
	'FontName',FontName, ...
	'FontSize',FontSize, ...
	'HorizontalAlignment','left', ...
	'ListboxTop',0, ...
	'Position',[20 45 100 12].*PosChange, ...
	'String','Elevation Fixed focus,', ...
	'Style','text', ...
	'Tag','rimoText');
h1 = uicontrol('Parent',h0, ...
	'Units','points', ...
	'BackgroundColor',[0.8 0.8 0.8], ...
	'FontName',FontName, ...
	'FontSize',FontSize, ...
	'HorizontalAlignment','left', ...
	'ListboxTop',0, ...
	'Position',[20 60 160 12].*PosChange, ...
	'String','Elevation # points', ...
	'Style','text', ...
	'Tag','Mp_elText');
h1 = uicontrol('Parent',h0, ...
	'Units','points', ...
	'BackgroundColor',[0.8 0.8 0.8], ...
	'FontName',FontName, ...
	'FontSize',FontSize, ...
	'HorizontalAlignment','left', ...
	'ListboxTop',0, ...
	'Position',[20 75 160 12].*PosChange, ...
	'String','Elevation # elements', ...
	'Style','text', ...
	'Tag','Me_elText');
h1 = uicontrol('Parent',h0, ...
	'Units','points', ...
	'BackgroundColor',[0.8 0.8 0.8], ...
	'FontName',FontName, ...
	'FontSize',FontSize, ...
	'HorizontalAlignment','left', ...
	'ListboxTop',0, ...
	'Position',[20 90 160 12].*PosChange, ...
	'String','Elevation array-aperture,', ...
	'Style','text', ...
	'Tag','aimoText');
h1 = uicontrol('Parent',h0, ...
	'Units','points', ...
	'BackgroundColor',[0.8 0.8 0.8], ...
	'FontName',FontName, ...
	'FontSize',FontSize, ...
	'HorizontalAlignment','left', ...
	'ListboxTop',0, ...
	'Position',[20 105 160 12].*PosChange, ...
	'String','Elevation array-aperture', ...
	'Style','text', ...
	'Tag','aText');
h1 = uicontrol('Parent',h0, ...
	'Units','points', ...
	'BackgroundColor',[0.8 0.8 0.8], ...
	'FontName',FontName, ...
	'FontSize',FontSize, ...
	'HorizontalAlignment','left', ...
	'ListboxTop',0, ...
	'Position',[20 120 160 12].*PosChange, ...
	'String','ELEVATION:', ...
	'Style','text', ...
	'Tag','ElText');
h1 = uicontrol('Parent',h0, ...
	'Units','points', ...
	'BackgroundColor',[0.8 0.8 0.8], ...
	'FontName',FontName, ...
	'FontSize',FontSize, ...
	'HorizontalAlignment','left', ...
	'ListboxTop',0, ...
	'Position',[20 140 160 12].*PosChange, ...
	'String','Azimuth # points per element', ...
	'Style','text', ...
	'Tag','Np_azText');
h1 = uicontrol('Parent',h0, ...
	'Units','points', ...
	'BackgroundColor',[0.8 0.8 0.8], ...
	'FontName',FontName, ...
	'FontSize',FontSize, ...
	'HorizontalAlignment','left', ...
	'ListboxTop',0, ...
	'Position',[20 155 160 12].*PosChange, ...
	'String','Azimuth # elements', ...
	'Style','text', ...
	'Tag','Ne_azText');
h1 = uicontrol('Parent',h0, ...
	'Units','points', ...
	'BackgroundColor',[0.8 0.8 0.8], ...
	'FontName',FontName, ...
	'FontSize',FontSize, ...
	'HorizontalAlignment','left', ...
	'ListboxTop',0, ...
	'Position',[20 170 160 12].*PosChange, ...
	'String','Curved array angle', ...
	'Style','text', ...
	'Tag','cangText');
h1 = uicontrol('Parent',h0, ...
	'Units','points', ...
	'BackgroundColor',[0.8 0.8 0.8], ...
	'FontName',FontName, ...
	'FontSize',FontSize, ...
	'HorizontalAlignment','left', ...
	'ListboxTop',0, ...
	'Position',[20 185 160 12].*PosChange, ...
	'String','Curved array arc', ...
	'Style','text', ...
	'Tag','carcText');
h1 = uicontrol('Parent',h0, ...
	'Units','points', ...
	'BackgroundColor',[0.8 0.8 0.8], ...
	'FontName',FontName, ...
	'FontSize',FontSize, ...
	'HorizontalAlignment','left', ...
	'ListboxTop',0, ...
	'Position',[20 200 160 12].*PosChange, ...
	'String','Azimuth array-aperture', ...
	'Style','text', ...
	'Tag','dText');
h1 = uicontrol('Parent',h0, ...
	'Units','points', ...
	'BackgroundColor',[0.8 0.8 0.8], ...
	'FontName',FontName, ...
	'FontSize',FontSize, ...
	'HorizontalAlignment','left', ...
	'ListboxTop',0, ...
	'Position',[20 215 160 12].*PosChange, ...
	'String','AZIMUTH:', ...
	'Style','text', ...
	'Tag','AzText');
h1 = uicontrol('Parent',h0, ...
	'Units','points', ...
	'BackgroundColor',[0.8 0.8 0.8], ...
	'FontName',FontName, ...
	'FontSize',FontSize, ...
	'HorizontalAlignment','left', ...
	'ListboxTop',0, ...
	'Position',[20 235 160 12].*PosChange, ...
	'String','Radius of curvature', ...
	'Style','text', ...
	'Tag','ROCText');
h1 = uicontrol('Parent',h0, ...
	'Units','points', ...
	'BackgroundColor',[0.8 0.8 0.8], ...
	'FontName',FontName, ...
	'FontSize',FontSize, ...
	'HorizontalAlignment','left', ...
	'ListboxTop',0, ...
	'Position',[20 255 160 12].*PosChange, ...
	'String','Transducer footprint (>=0)', ...
	'Style','text', ...
	'Tag','ShapeText');
h1 = uicontrol('Parent',h0, ...
	'Units','points', ...
	'BackgroundColor',[0.8 0.8 0.8], ...
	'FontName',FontName, ...
	'FontSize',FontSize, ...
	'HorizontalAlignment','right', ...
	'ListboxTop',0, ...
	'Position',[200 30 40 12].*PosChange, ...
	'String','oo =', ...
	'Style','text', ...
	'Tag','DText');
h1 = uicontrol('Parent',h0, ...
	'Units','points', ...
	'BackgroundColor',[0.8 0.8 0.8], ...
	'FontName',FontName, ...
	'FontSize',FontSize, ...
	'HorizontalAlignment','right', ...
	'ListboxTop',0, ...
	'Position',[200 45 40 12].*PosChange, ...
	'String','ri =', ...
	'Style','text', ...
	'Tag','DText');
h1 = uicontrol('Parent',h0, ...
	'Units','points', ...
	'BackgroundColor',[0.8 0.8 0.8], ...
	'FontName',FontName, ...
	'FontSize',FontSize, ...
	'HorizontalAlignment','right', ...
	'ListboxTop',0, ...
	'Position',[200 60 40 12].*PosChange, ...
	'String','Mp_el =', ...
	'Style','text', ...
	'Tag','DText');
h1 = uicontrol('Parent',h0, ...
	'Units','points', ...
	'BackgroundColor',[0.8 0.8 0.8], ...
	'FontName',FontName, ...
	'FontSize',FontSize, ...
	'HorizontalAlignment','right', ...
	'ListboxTop',0, ...
	'Position',[200 75 40 12].*PosChange, ...
	'String','Me_el =', ...
	'Style','text', ...
	'Tag','DText');
h1 = uicontrol('Parent',h0, ...
	'Units','points', ...
	'BackgroundColor',[0.8 0.8 0.8], ...
	'FontName',FontName, ...
	'FontSize',FontSize, ...
	'HorizontalAlignment','right', ...
	'ListboxTop',0, ...
	'Position',[200 90 40 12].*PosChange, ...
	'String','ai =', ...
	'Style','text', ...
	'Tag','aimoDText');
h1 = uicontrol('Parent',h0, ...
	'Units','points', ...
	'BackgroundColor',[0.8 0.8 0.8], ...
	'FontName',FontName, ...
	'FontSize',FontSize, ...
	'HorizontalAlignment','right', ...
	'ListboxTop',0, ...
	'Position',[200 105 40 12].*PosChange, ...
	'String','a =', ...
	'Style','text', ...
	'Tag','DText');
h1 = uicontrol('Parent',h0, ...
	'Units','points', ...
	'BackgroundColor',[0.8 0.8 0.8], ...
	'FontName',FontName, ...
	'FontSize',FontSize, ...
	'HorizontalAlignment','right', ...
	'ListboxTop',0, ...
	'Position',[200 140 40 12].*PosChange, ...
	'String','Np_az =', ...
	'Style','text', ...
	'Tag','DText');
h1 = uicontrol('Parent',h0, ...
	'Units','points', ...
	'BackgroundColor',[0.8 0.8 0.8], ...
	'FontName',FontName, ...
	'FontSize',FontSize, ...
	'HorizontalAlignment','right', ...
	'ListboxTop',0, ...
	'Position',[200 155 40 12].*PosChange, ...
	'String','Ne_az =', ...
	'Style','text', ...
	'Tag','DText');
h1 = uicontrol('Parent',h0, ...
	'Units','points', ...
	'BackgroundColor',[0.8 0.8 0.8], ...
	'FontName',FontName, ...
	'FontSize',FontSize, ...
	'HorizontalAlignment','right', ...
	'ListboxTop',0, ...
	'Position',[200 170 40 12].*PosChange, ...
	'String','=', ...
	'Style','text', ...
	'Tag','DText');
h1 = uicontrol('Parent',h0, ...
	'Units','points', ...
	'BackgroundColor',[0.8 0.8 0.8], ...
	'FontName',FontName, ...
	'FontSize',FontSize, ...
	'HorizontalAlignment','right', ...
	'ListboxTop',0, ...
	'Position',[200 185 40 12].*PosChange, ...
	'String','=', ...
	'Style','text', ...
	'Tag','DText');
h1 = uicontrol('Parent',h0, ...
	'Units','points', ...
	'BackgroundColor',[0.8 0.8 0.8], ...
	'FontName',FontName, ...
	'FontSize',FontSize, ...
	'HorizontalAlignment','right', ...
	'ListboxTop',0, ...
	'Position',[200 200 40 12].*PosChange, ...
	'String','d =', ...
	'Style','text', ...
	'Tag','DText');
h1 = uicontrol('Parent',h0, ...
	'Units','points', ...
	'BackgroundColor',[0.8 0.8 0.8], ...
	'FontName',FontName, ...
	'FontSize',FontSize, ...
	'HorizontalAlignment','right', ...
	'ListboxTop',0, ...
	'Position',[200 235 40 12].*PosChange, ...
	'String','ROC =', ...
	'Style','text', ...
	'Tag','DText');
h1 = uicontrol('Parent',h0, ...
	'Units','points', ...
	'BackgroundColor',[0.8 0.8 0.8], ...
	'FontName',FontName, ...
	'FontSize',FontSize, ...
	'HorizontalAlignment','left', ...
	'ListboxTop',0, ...
	'Position',[310 30 30 12].*PosChange, ...
	'String','mm =', ...
	'Style','text', ...
	'Tag','DText');
h1 = uicontrol('Parent',h0, ...
	'Units','points', ...
	'BackgroundColor',[0.8 0.8 0.8], ...
	'FontName',FontName, ...
	'FontSize',FontSize, ...
	'HorizontalAlignment','left', ...
	'ListboxTop',0, ...
	'Position',[310 45 30 12].*PosChange, ...
	'String','mm =', ...
	'Style','text', ...
	'Tag','DText');
h1 = uicontrol('Parent',h0, ...
	'Units','points', ...
	'BackgroundColor',[0.8 0.8 0.8], ...
	'FontName',FontName, ...
	'FontSize',FontSize, ...
	'HorizontalAlignment','left', ...
	'ListboxTop',0, ...
	'Position',[310 90 30 12].*PosChange, ...
	'String','mm =', ...
	'Style','text', ...
	'Tag','DText');
h1 = uicontrol('Parent',h0, ...
	'Units','points', ...
	'BackgroundColor',[0.8 0.8 0.8], ...
	'FontName',FontName, ...
	'FontSize',FontSize, ...
	'HorizontalAlignment','left', ...
	'ListboxTop',0, ...
	'Position',[310 105 30 12].*PosChange, ...
	'String','mm =', ...
	'Style','text', ...
	'Tag','DText');
h1 = uicontrol('Parent',h0, ...
	'Units','points', ...
	'BackgroundColor',[0.8 0.8 0.8], ...
	'FontName',FontName, ...
	'FontSize',FontSize, ...
	'HorizontalAlignment','left', ...
	'ListboxTop',0, ...
	'Position',[310 170 30 12].*PosChange, ...
	'String','deg', ...
	'Style','text', ...
	'Tag','DText');
h1 = uicontrol('Parent',h0, ...
	'Units','points', ...
	'BackgroundColor',[0.8 0.8 0.8], ...
	'FontName',FontName, ...
	'FontSize',FontSize, ...
	'HorizontalAlignment','left', ...
	'ListboxTop',0, ...
	'Position',[310 185 30 12].*PosChange, ...
	'String','mm =', ...
	'Style','text', ...
	'Tag','DText');
h1 = uicontrol('Parent',h0, ...
	'Units','points', ...
	'BackgroundColor',[0.8 0.8 0.8], ...
	'FontName',FontName, ...
	'FontSize',FontSize, ...
	'HorizontalAlignment','left', ...
	'ListboxTop',0, ...
	'Position',[310 200 30 12].*PosChange, ...
	'String','mm =', ...
	'Style','text', ...
	'Tag','DText');
h1 = uicontrol('Parent',h0, ...
	'Units','points', ...
	'BackgroundColor',[0.8 0.8 0.8], ...
	'FontName',FontName, ...
	'FontSize',FontSize, ...
	'HorizontalAlignment','left', ...
	'ListboxTop',0, ...
	'Position',[310 235 30 12].*PosChange, ...
	'String','mm =', ...
	'Style','text', ...
	'Tag','DText');
h1 = uicontrol('Parent',h0, ...
	'Units','points', ...
	'BackgroundColor',[0.8 0.8 0.8], ...
	'FontName',FontName, ...
	'FontSize',FontSize, ...
	'HorizontalAlignment','left', ...
	'ListboxTop',0, ...
	'Position',[275 255 20 12].*PosChange, ...
	'String','or', ...
	'Style','text', ...
	'Tag','DText');
h1 = uicontrol('Parent',h0, ...
	'Units','points', ...
	'BackgroundColor',[0.8 0.8 0.8], ...
	'FontName',FontName, ...
	'FontSize',FontSize, ...
	'HorizontalAlignment','left', ...
	'ListboxTop',0, ...
	'Position',[405 30 35 12].*PosChange, ...
	'String','lambda', ...
	'Style','text', ...
	'Tag','DText');
h1 = uicontrol('Parent',h0, ...
	'Units','points', ...
	'BackgroundColor',[0.8 0.8 0.8], ...
	'FontName',FontName, ...
	'FontSize',FontSize, ...
	'HorizontalAlignment','left', ...
	'ListboxTop',0, ...
	'Position',[405 45 35 12].*PosChange, ...
	'String','lambda', ...
	'Style','text', ...
	'Tag','DText');
h1 = uicontrol('Parent',h0, ...
	'Units','points', ...
	'BackgroundColor',[0.8 0.8 0.8], ...
	'FontName',FontName, ...
	'FontSize',FontSize, ...
	'HorizontalAlignment','left', ...
	'ListboxTop',0, ...
	'Position',[405 90 35 12].*PosChange, ...
	'String','lambda', ...
	'Style','text', ...
	'Tag','DText');
h1 = uicontrol('Parent',h0, ...
	'Units','points', ...
	'BackgroundColor',[0.8 0.8 0.8], ...
	'FontName',FontName, ...
	'FontSize',FontSize, ...
	'HorizontalAlignment','left', ...
	'ListboxTop',0, ...
	'Position',[405 105 35 12].*PosChange, ...
	'String','lambda', ...
	'Style','text', ...
	'Tag','DText');
h1 = uicontrol('Parent',h0, ...
	'Units','points', ...
	'BackgroundColor',[0.8 0.8 0.8], ...
	'FontName',FontName, ...
	'FontSize',FontSize, ...
	'HorizontalAlignment','left', ...
	'ListboxTop',0, ...
	'Position',[405 185 35 12].*PosChange, ...
	'String','lambda', ...
	'Style','text', ...
	'Tag','DText');
h1 = uicontrol('Parent',h0, ...
	'Units','points', ...
	'BackgroundColor',[0.8 0.8 0.8], ...
	'FontName',FontName, ...
	'FontSize',FontSize, ...
	'HorizontalAlignment','left', ...
	'ListboxTop',0, ...
	'Position',[405 200 35 12].*PosChange, ...
	'String','lambda', ...
	'Style','text', ...
	'Tag','DText');
h1 = uicontrol('Parent',h0, ...
	'Units','points', ...
	'BackgroundColor',[0.8 0.8 0.8], ...
	'FontName',FontName, ...
	'FontSize',FontSize, ...
	'HorizontalAlignment','left', ...
	'ListboxTop',0, ...
	'Position',[405 235 35 12].*PosChange, ...
	'String','lambda', ...
	'Style','text', ...
	'Tag','DText');
h1 = uicontrol('Parent',h0, ...
	'Units','points', ...
	'BackgroundColor',[1 1 1], ...
	'Callback',mat1, ...
	'FontName',FontName, ...
	'FontSize',FontSize, ...
	'HorizontalAlignment','right', ...
	'ListboxTop',0, ...
	'Position',[210 255 60 13].*PosChange, ...
	'Style','edit', ...
	'Tag','ShapeEdit');
h1 = uicontrol('Parent',h0, ...
	'Units','points', ...
	'BackgroundColor',[0.752941176470588 0.752941176470588 0.752941176470588], ...
	'Callback',mat2, ...
	'FontName',FontName, ...
	'FontSize',FontSize, ...
	'ListboxTop',0, ...
	'Position',[290 258 150 12].*PosChange, ...
	'String',mat3, ...
	'Style','popupmenu', ...
	'Tag','ShapeMenu', ...
	'Value',1);
h1 = uicontrol('Parent',h0, ...
	'Units','points', ...
	'BackgroundColor',[1 1 1], ...
	'Callback',mat1, ...
	'FontName',FontName, ...
	'FontSize',FontSize, ...
	'HorizontalAlignment','right', ...
	'ListboxTop',0, ...
	'Position',[245 235 60 13].*PosChange, ...
	'Style','edit', ...
	'Tag','ROCmm');
h1 = uicontrol('Parent',h0, ...
	'Units','points', ...
	'BackgroundColor',[1 1 1], ...
	'Callback',mat1, ...
	'FontName',FontName, ...
	'FontSize',FontSize, ...
	'HorizontalAlignment','right', ...
	'ListboxTop',0, ...
	'Position',[340 235 60 13].*PosChange, ...
	'Style','edit', ...
	'Tag','ROClambda');
h1 = uicontrol('Parent',h0, ...
	'Units','points', ...
	'BackgroundColor',[1 1 1], ...
	'Callback',mat1, ...
	'FontName',FontName, ...
	'FontSize',FontSize, ...
	'HorizontalAlignment','right', ...
	'ListboxTop',0, ...
	'Position',[245 200 60 13].*PosChange, ...
	'Style','edit', ...
	'Tag','dmm');
h1 = uicontrol('Parent',h0, ...
	'Units','points', ...
	'BackgroundColor',[1 1 1], ...
	'Callback',mat1, ...
	'FontName',FontName, ...
	'FontSize',FontSize, ...
	'HorizontalAlignment','right', ...
	'ListboxTop',0, ...
	'Position',[340 200 60 13].*PosChange, ...
	'Style','edit', ...
	'Tag','dlambda');
h1 = uicontrol('Parent',h0, ...
	'Units','points', ...
	'BackgroundColor',[1 1 1], ...
	'Callback',mat1, ...
	'FontName',FontName, ...
	'FontSize',FontSize, ...
	'HorizontalAlignment','right', ...
	'ListboxTop',0, ...
	'Position',[245 185 60 13].*PosChange, ...
	'Style','edit', ...
	'Tag','carcmm');
h1 = uicontrol('Parent',h0, ...
	'Units','points', ...
	'BackgroundColor',[1 1 1], ...
	'Callback',mat1, ...
	'FontName',FontName, ...
	'FontSize',FontSize, ...
	'HorizontalAlignment','right', ...
	'ListboxTop',0, ...
	'Position',[340 185 60 13].*PosChange, ...
	'Style','edit', ...
	'Tag','carclambda');
h1 = uicontrol('Parent',h0, ...
	'Units','points', ...
	'BackgroundColor',[1 1 1], ...
	'Callback',mat1, ...
	'FontName',FontName, ...
	'FontSize',FontSize, ...
	'HorizontalAlignment','right', ...
	'ListboxTop',0, ...
	'Position',[245 170 60 13].*PosChange, ...
	'Style','edit', ...
	'Tag','cang');
h1 = uicontrol('Parent',h0, ...
	'Units','points', ...
	'BackgroundColor',[1 1 1], ...
	'Callback',mat1, ...
	'FontName',FontName, ...
	'FontSize',FontSize, ...
	'HorizontalAlignment','right', ...
	'ListboxTop',0, ...
	'Position',[245 155 60 13].*PosChange, ...
	'Style','edit', ...
	'Tag','Ne_az');
h1 = uicontrol('Parent',h0, ...
	'Units','points', ...
	'BackgroundColor',[1 1 1], ...
	'Callback',mat1, ...
	'FontName',FontName, ...
	'FontSize',FontSize, ...
	'HorizontalAlignment','right', ...
	'ListboxTop',0, ...
	'Position',[245 140 60 13].*PosChange, ...
	'Style','edit', ...
	'Tag','Np_az');
h1 = uicontrol('Parent',h0, ...
	'Units','points', ...
	'BackgroundColor',[1 1 1], ...
	'Callback',mat1, ...
	'FontName',FontName, ...
	'FontSize',FontSize, ...
	'HorizontalAlignment','right', ...
	'ListboxTop',0, ...
	'Position',[245 105 60 13].*PosChange, ...
	'Style','edit', ...
	'Tag','amm');
h1 = uicontrol('Parent',h0, ...
	'Units','points', ...
	'BackgroundColor',[1 1 1], ...
	'Callback',mat1, ...
	'FontName',FontName, ...
	'FontSize',FontSize, ...
	'HorizontalAlignment','right', ...
	'ListboxTop',0, ...
	'Position',[340 105 60 13].*PosChange, ...
	'Style','edit', ...
	'Tag','alambda');
h1 = uicontrol('Parent',h0, ...
	'Units','points', ...
	'BackgroundColor',[0.752941176470588 0.752941176470588 0.752941176470588], ...
	'Callback',mat2, ...
	'FontName',FontName, ...
	'FontSize',FontSize, ...
	'ListboxTop',0, ...
	'Position',[135 93 55 12].*PosChange, ...
	'String',mat4, ...
	'Style','popupmenu', ...
	'Tag','aimoMenu', ...
	'Value',1);
h1 = uicontrol('Parent',h0, ...
	'Units','points', ...
	'BackgroundColor',[1 1 1], ...
	'Callback',mat1, ...
	'FontName',FontName, ...
	'FontSize',FontSize, ...
	'HorizontalAlignment','right', ...
	'ListboxTop',0, ...
	'Position',[245 90 60 13].*PosChange, ...
	'Style','edit', ...
	'Tag','aimomm');
h1 = uicontrol('Parent',h0, ...
	'Units','points', ...
	'BackgroundColor',[1 1 1], ...
	'Callback',mat1, ...
	'FontName',FontName, ...
	'FontSize',FontSize, ...
	'HorizontalAlignment','right', ...
	'ListboxTop',0, ...
	'Position',[340 90 60 13].*PosChange, ...
	'Style','edit', ...
	'Tag','aimolambda');
h1 = uicontrol('Parent',h0, ...
	'Units','points', ...
	'BackgroundColor',[1 1 1], ...
	'Callback',mat1, ...
	'FontName',FontName, ...
	'FontSize',FontSize, ...
	'HorizontalAlignment','right', ...
	'ListboxTop',0, ...
	'Position',[245 75 60 13].*PosChange, ...
	'Style','edit', ...
	'Tag','Me_el');
h1 = uicontrol('Parent',h0, ...
	'Units','points', ...
	'BackgroundColor',[1 1 1], ...
	'Callback',mat1, ...
	'FontName',FontName, ...
	'FontSize',FontSize, ...
	'HorizontalAlignment','right', ...
	'ListboxTop',0, ...
	'Position',[245 60 60 13].*PosChange, ...
	'Style','edit', ...
	'Tag','Mp_el');
h1 = uicontrol('Parent',h0, ...
	'Units','points', ...
	'BackgroundColor',[0.752941176470588 0.752941176470588 0.752941176470588], ...
	'Callback',mat2, ...
	'FontName',FontName, ...
	'FontSize',FontSize, ...
	'ListboxTop',0, ...
	'Position',[125 50 50 12].*PosChange, ...
	'String',mat4, ...
	'Style','popupmenu', ...
	'Tag','rimoMenu', ...
	'Value',1);
h1 = uicontrol('Parent',h0, ...
	'Units','points', ...
	'BackgroundColor',[1 1 1], ...
	'Callback',mat1, ...
	'FontName',FontName, ...
	'FontSize',FontSize, ...
	'HorizontalAlignment','right', ...
	'ListboxTop',0, ...
	'Position',[245 45 60 13].*PosChange, ...
	'Style','edit', ...
	'Tag','rimomm');
h1 = uicontrol('Parent',h0, ...
	'Units','points', ...
	'BackgroundColor',[1 1 1], ...
	'Callback',mat1, ...
	'FontName',FontName, ...
	'FontSize',FontSize, ...
	'HorizontalAlignment','right', ...
	'ListboxTop',0, ...
	'Position',[340 45 60 13].*PosChange, ...
	'Style','edit', ...
	'Tag','rimolambda');
h1 = uicontrol('Parent',h0, ...
	'Units','points', ...
	'BackgroundColor',[0.752941176470588 0.752941176470588 0.752941176470588], ...
	'Callback',mat2, ...
	'FontName',FontName, ...
	'FontSize',FontSize, ...
	'ListboxTop',0, ...
	'Position',[95 31 50 12].*PosChange, ...
	'String',mat5, ...
	'Style','popupmenu', ...
	'Tag','omoMenu', ...
	'Value',1);
h1 = uicontrol('Parent',h0, ...
	'Units','points', ...
	'BackgroundColor',[1 1 1], ...
	'Callback',mat1, ...
	'FontName',FontName, ...
	'FontSize',FontSize, ...
	'HorizontalAlignment','right', ...
	'ListboxTop',0, ...
	'Position',[245 30 60 13].*PosChange, ...
	'Style','edit', ...
	'Tag','omomm');
h1 = uicontrol('Parent',h0, ...
	'Units','points', ...
	'BackgroundColor',[1 1 1], ...
	'Callback',mat1, ...
	'FontName',FontName, ...
	'FontSize',FontSize, ...
	'HorizontalAlignment','right', ...
	'ListboxTop',0, ...
	'Position',[340 30 60 13].*PosChange, ...
	'Style','edit', ...
	'Tag','omolambda');
h1 = uicontrol('Parent',h0, ...
	'Units','points', ...
	'BackgroundColor',[0.752941176470588 0.752941176470588 0.752941176470588], ...
	'Callback',mat6, ...
	'FontName',FontName, ...
	'FontSize',FontSize, ...
	'ListboxTop',0, ...
	'Position',[340 5 95 20].*PosChange, ...
	'String','Close', ...
	'Tag','CloseButton');
if nargout > 0, fig = h0; end

transducer = t1usimgui('ROCmm','',transducer,flagg,excitation,media);