%-----------------------------------------------------------------------------
% Function    : bp_wc
%
% Description : Find worst case cut through a 2D beam pattern
%
%
% Language    : Matlab 5
% Written by  : Andreas Austeng, IFI
%
% Version no. : 1.0 AA 01.01.2000 first version
%                   SH 17.08.2000 Axis, labels added
%                   SH 23.08.00   Improved label
%
% Called by   : resp2d
% Calling     : 
% -----------------------------------------------------------------------------
%function [varargout] = bp_wc(varargin)


function [varargout] = bp_wc(varargin)
% 
% parameters:
  no_theta = 181;
  
  
BP = varargin{1};
  [m,n]  = size(BP);

  if (m~=n), error('BP should be square'); end
  
  if nargin == 3,
    ax = varargin{3};
  else
    ax = [1:m];
    ax = linspace(-1,1,m);
  end
  

  start = - (m-1)/2;
  stop  = (m-1)/2;
    
  XX = repmat(start:stop,no_theta,1);
  YY = repmat(start:stop,no_theta,1);
  Theta = -pi/2:pi/(no_theta-1):pi/2;
  
  for i=1:no_theta
    XX(i,:) = XX(i,:) * cos(Theta(i));
    YY(i,:) = YY(i,:) * sin(Theta(i));
  end

  B = interp2(start:stop,start:stop,BP,XX,YY);
  B = max(B);

  if nargout == 0, 
    hold on
    if nargin > 1,
      Col = varargin{2};
      plot(ax,B,Col,'LineWidth',2);
    else
      plot(ax,B,'r','LineWidth',2);
    end
    hold off
  else
    plot(ax,B,'k','LineWidth',2);
    grid
    drawnow
    varargout{1} = B;
  end
    xlabel('(u^2 + v^2)^{1/2}')
    ylabel('dB')
    title('Worst-case cut through 2D beampattern')
  
