% -----------------------------------------------------------------------------
% Function    : ffmain(plotfig, elem_pts, flagg, media, ...
%               excitation, transducer, 
%               config,configOrigHandle, plotfigOrigHandle)
%
% Description : Far-field response main routine. Detects transducer
%               type and calls the correct calculation routine. It handles
%               planar 1D and 2D symmetric planar transducers.
%
%
% Language    : Matlab 4.2
% Written by  : Bjrnar Elgetun, Ifi-UiO
%
% Version no. : 1.0 BJE 23.11.95 first version
%               1.1 BJE 01.12.95 small change
%               1.2  SH 20.02.96 Removed test for symmetric transducer
%               1.3  SH 10.05.96 Removed test for even no of elements
%               1.4  SH 03.01.96 centers as input and sent to resp1d
%               1.5  AA 19.06.97 Added choice for 1- or 2-way response
%                    AA 17.08.00  3 more variables in call of resp2d
%                                 3 more variables in call of this function
%                                 
%                
%
% Called by   : usimcnf
% Calling     : resp1d, resp2d
% -----------------------------------------------------------------------------

function ffmain(plotfig,elem_pts,flagg,media,excitation,transducer,centers,...
	       		config, configOrigHandle, plotfigOrigHandle)

%
% initialize
%
  active=find(elem_pts(4,:) > 0);	% find active transducer elements
  active_left=find(elem_pts(1,:) < 0 & elem_pts(4,:) > 0);    % in left halfplane
  active_right=find(elem_pts(1,:) > 0 & elem_pts(4,:) > 0);   % in right halfplane

  N_full=length(elem_pts(1,:));		% # elements in full transducer
  N_active=length(active);		% # active elements

  if all(elem_pts(2,:) == 0)		% detect transducertype
      type='1d';
    else
      type='2d';
  end

%
% check transducer
%
 sleft = size(active_left);
 sright = size(active_right);
 smin = min(sleft,sright); 


%  if ~(ceil(N_active/2) == floor(N_active/2))
%      fprintf('ERROR: Calculation only implemented for EVEN transducers.\n\n');
%      return;
%  end 
%
% compute far-field response.
%
  if strcmp(type,'1d')
    if (round(vinput('type of response ( 1- or 2-way )',1,2,1))==1)
      resp1d(plotfig,[],elem_pts,flagg,media,excitation,transducer,0,1,centers,1);
    else
      resp1d(plotfig,[],elem_pts,flagg,media,excitation,transducer,0,1,centers,-1);
    end
  
  else
    
    resp2d(plotfig,[],elem_pts,flagg,media,excitation,transducer,0,1, ...
    		config, configOrigHandle, plotfigOrigHandle);

    
  end


  fprintf('\n\nFinished calculation!\n');










