%------------------------------------------------------------------------
% Routine     : listusim.m
% 
% Description : List all parameters to screen, ascii-file or printer, 
%               depending on ACTION parameter
%
%               ACTION   'screen'
%                        'file'
%                        'printer'
%
% 
% Language    : MATLAB 4.1 
% Originator  : Vebjoern Berre (IBT)
%
% Version no. : 3.0 VEB 12.05.93
%               3.1 TKL 13.07.93 Switching xyz->rhp if necessary.
%               3.2 TKL 06.09.93 Added ausimtxt
%               3.3 TKL 22.09.93 Removed ausimtxt
%               3.4 FT  19.01.94 Added abrmenu
%               3.5 FT  15.02.94 test before converting excitation(2:4)
%               3.6 FT  20.03.94 Removed some obs.options & 'linjeparametre'
%               3.7 SH  30.11.94 Corrected output to file
%               3.8 SH  12.12.94 Shortened filenames to 8 characters
%               3.9 SH  13.12.94 Enabled observation listing for movie
%               4.0 SH  14.02.95 Added output of comment (extra variable in call)
%               4.1 LO  31.03.95 elecdelt and elecdelr added in header when flagg(1)==2.
%               4.2 BJE 28.04.95 Changed function call, added ACTION, d,
%               removed fid
%               4.3 SH  16.05.95 Replace !rm and !del with delete
%               4.4 SH  15.09.95 Fix in output of beamforming parameters
%               4.5 SH  15.03.99 Can set comment, fix focusing parameters
%                                comment is returned

%
% Called by   : usimcnf, layers
% Calling     : listinit, eusimtxt, busimtxt, musumtxt, o1usimtx,
%               o2ausimt, o3usimtx, t1usimtx,
%               t3usimtx, xyz2rhp, rhp2xyz
% ------------------------------------------------------------------------

function comment = listusim(ACTION,excitation,media,observasjon,transducer, ...
      option,flagg,comment,elecdelt,elecdelr,separator,printercmd)
  
%
% initialize
%
  c=eval('cd');			% actual directory
  dd=eval('datetime');		% date and time
  
  
%
% OPEN file
%
  if strcmp(ACTION,'screen')
      
      fid=1;		
      
    elseif strcmp(ACTION,'file')
      
      temp=input('List configuration to file > ','s');		% get filename
      fid=fopen(temp,'w');					% open file
      fprintf(fid,['\n',c,separator,temp,', ',dd,'\n\n']);	% tag heading
      
    elseif strcmp(ACTION,'printer')
      
      fid=fopen('tempfil','w');					% open file
      
  end
  
  listinit;  
%
% print and set comment 
%
  if strcmp(ACTION,'file')|strcmp(ACTION,'printer')
    if exist('comment')
      disp('Current comment : ')
      disp(' ');
      disp(comment);    
    end
    tmp=input('-> Enter comment (return for keep old) : ','s');
    if ~isempty(tmp) 
      comment = tmp;
    end 
  end  
  
  fprintf(fid,'\n');
  fprintf(fid,comment);
  fprintf(fid,'\n');
  fprintf(fid,'\n');
  
  
  if flagg(1)==2 
      
% MISSING print elecdelt, elecdelr here ???
      
  end
  
  
%
% print transducer information
%
  if flagg(2)==1
%      lambda = media(1,2)/excitation(1);
%      t1usimtx(transducer, lambda);
      t1usimtx
    elseif flagg(2)==3
      t3usimtx;
  end
  
  
%
% print excitation information
%
  eusimtxt;
  
  
%
% print beamforming information
%
%  if flagg(4)==3 & flagg(1)==1 & flagg(2)==1;
%      [excitation(2),excitation(3),excitation(4)] = ...
%          xyz2rhp(excitation(2),excitation(3),excitation(4));
%  end
%
% copied from busim.m 15.03.99; SH
%
  if flagg(4)==1
% convert from rectangular coordinates  
  fast=['xyzt'];
  
  [excitation(2),excitation(3),excitation(4)] = ... 
          rhp2xyz(excitation(2),excitation(3),excitation(4));
elseif flagg(4)==3
  fast=['rhpt'];
elseif flagg(4) == 4
  fast=['rest'];
% convert parameters
  excitation(3:4)=sin(excitation(3:4));
end
  
  busimtxt;
  
  
%
% print medium information
%
%  if flagg(4)==3 & flagg(1)==1 & flagg(2)==1;
%      [excitation(2),excitation(3),excitation(4)] = ...
%          rhp2xyz(excitation(2),excitation(3),excitation(4));
%  end
  musimtxt;
  
  
%
% print observation information
%
  if option(1)=='p'
      o1usimtx;
    elseif option(1)=='1' 
      o2ausimt;
    elseif option(1)=='2' | option(1) =='m'
      o3usimtx(observasjon,option,flagg,excitation,fast,fid);
  end
  
%
% print abr.... information
%
  if flagg(3)==2
      abrmenu;
  end
  
  
%
% CLOSE file if open
%
  if strcmp(ACTION,'file') | strcmp(ACTION,'printer')
      fclose(fid);
  end
  
  
%
% ACTION 'printer' file to printer
%
  if strcmp(ACTION,'printer')
  
      disp('sending to printer ...');
 
      eval([printercmd,' tempfil']);
      delete tempfil;

  end
  

  fprintf('\n\nFinished!\n');


