%----------------------------------------------------------------
% Routine     : pec.m 
%
% Description : Inner loop of pecomp.m - field calculation
%
% Language    : Matlab V4.0
% Written by  : 1.0 SH 13.08.96 Code taken from pecomp.m
% Version no. : 1.1 SH 04.09.96 extracted F_des=val(8) and c_foc 
%               1.2 SH 11.11.96 Added definition of Ne_az
%               1.3 SH 23.01.98 Check dimensions for resp 2/3 dep on 
%                               ver 4 or 5 of matlab
%               1.4 SH 07.04.98 Corrected dimension of resp for ver 4 & ver 5
%                               added attenuation
%               1.5 SH 14.04.98 Soft baffle boundary conditions (cosine-factor)
%               1.6 LO 08.06.98 cosine-factor included for nonplanar arrays also
%               1.7 SH 15.03.99 cosine-factor commented out, too many errors!
%
% Called by   : pecomp.m
% Calling     : focus, cos_fact
%----------------------------------------------------------------

  function [resp,max_resp,min_resp]=pec(x,y,z,t,elem_pts,Apodize,excitation,SteerFocusDelay,...
                             TimeStepVector,transducer,flagg,option,usr_resdir,delim,val,centers);

			 
  fprintf('\n*** COMPUTING RESPONSE IN M-FILE ***\n\n');
  co = computer;
  UNIX = co(1:2) ~= 'PC' & co(1:2) ~= 'MA';
%
% extract input parameters
% val=[r c PulseLength TLen omega Weight trans_arr_val F_des alfa beta];
%
  r = val(1);
  c = val(2);
  PulseLength = val(3);
  TLen = val(4);
  jomega = j*val(5);
  Weight = val(6);
  F_des = val(8);
  alfa  = val(9)/100;  % 1/cm
  beta  = val(10);
  freq  = val(5)/(2*pi*1e6);
  att = exp(-alfa*freq^beta); % per cm
  if (att ~=1),
    dB = -10*log10(att);
    disp(['Tissue attenuation: ',num2str(dB),' dB/cm or ',num2str(dB/freq), ...
	    ' dB/cm/MHz'])
  end
  att = att^(c/1e4); 			% per us
  %  
  fprintf('Hard baffle boundary conditions for each element\n\n')
  %%%%% fprintf('Soft baffle boundary conditions for each element\n\n')
  ElPt=size(elem_pts);
  d=transducer(1);
  Np_az=transducer(3);
  Ne_az=transducer(2);
  Mp_el=transducer(7);
  max_resp=[0 0]; min_resp=[0 0];	% real and imaginary part
  c_foc = excitation(14); % Speed of sound used when calculating 
% focusing delays.
%
% size of field
%
  FieldSize = size(x);
%  
% mod 23.01.98 SH:
%
  FieldLength = prod(size(x));
%  
% Main loop over TIME
%  
  for PNo = 1:TLen
      
%
% time reference / distance reference 
%
      if (option(3)=='y') | (option(3) == 'z')
          t_ref = t(1);
        else 
          t_ref = r / c;
      end
%
% put time array into a vector
%

% ------------------------------
% Check for 3D  by KE
      if option(1) == 'm' | option(1) == 'f'      % Changes for 3D
% ------------------------------
          Time = TimeStepVector(PNo)*ones(1,FieldLength);
        else
          Time = reshape(t,1,length(x(:)));
      end


      d_max = d;
      min_elem = 1;
      max_elem = ElPt(2);                        % changes for 3D  (down)
% ----------------------------
% Check for 3D by KE
      if (flagg(1) == 2) & ((option(1) == 'm') | (option(1) =='f')),% dynamic focus and movie ,
% ----------------------------
	    foc_depth = c*TimeStepVector(PNo);
	    if (F_des > 0) % dynamic aperture
	        d_max = min(d,foc_depth/F_des);
	
	        set = find(abs(elem_pts(1,:))<= d_max/2);
		max_elem = max(set);
		min_elem = min(set);
		disp(['f-number: ',num2str(max(F_des,foc_depth/d_max)),', aperture: ', ...
			num2str(d_max*1000),' mm, element range: ', ...
			num2str(min_elem),'- ', num2str(max_elem)]);
	    else 			% fixed aperture
	        d_max = d;
            end
%
% find time delay if dynamic focus
% corrected order of variables May 11, 1995 SH
%
	    input = [excitation(1), foc_depth, excitation(3:length(excitation))];%
	    [SteerFocusDelay,ctr] = focus(input,c_foc,transducer,elem_pts,centers,flagg);
      end
%
% initialize
%
      resp = zeros(1,FieldLength) + j*zeros(1,FieldLength);
%
% Loop over SOURCE POINTS
%

      for n = min_elem:max_elem
%
% print message
%
          if rem(n,10) == 0
	    if UNIX,
	      
                fprintf('Loop %3.0f of %3.0f now at %4.0f of totally %4.0f computations\r',PNo,TLen,n,ElPt(2));
            else
		fprintf('Loop 		%3.0f of %3.0f now at %4.0f of %4.0f computations\n', ...
                        PNo,TLen,n,ElPt(2));
            end  
	  end
%
% actual analysis point is
%
          x0 = elem_pts(1,n);
          y0 = elem_pts(2,n);
          z0 = elem_pts(3,n);
%
% compute field points
%
          [FieldPts] = xyz2fpts(x-x0,y-y0,z-z0);
%
% propagation delay from origin to field points and current time
%
          TimeDel = sqrt(sum(FieldPts.*FieldPts))/c;
%
% Steering and Focusing TimeDelay for the current element
% (one delay is for every point is computed from phase center of the 
%  points within the element, all points within the element has the
%  same delay) 
%
          TStFo = - SteerFocusDelay(n); 
%
% check if PulseLength is Finite
%
          if finite(PulseLength)
%
% Steering and Focusing TimeDelay for the current element, current 
% time and pulselength says where the pulse can be placed
%
              maxt = TStFo + PulseLength/2;
              mint = TStFo - PulseLength/2;
%
% find where the transmitted burst is placed
%
              isalive=find(((TimeDel-Time-eps)<=maxt)&((TimeDel-Time+eps)>=mint));
%
% find the actual time for the response computation
%
              t_vector = TimeDel(isalive) - Time(isalive) - TStFo;
%
% compute the weight and the attenuation correction factor
%
              if Weight == 1
                  w_pulse  = cos(pi*t_vector/PulseLength).^2;
                elseif Weight == 0
                  w_pulse  = 1;
              end

% 
% cosine of angle of incidene:  (LO: 05.06.98)          
%
              obs=xyz2fpts(x,y,z);
              xtmp=obs(1,isalive);
              ytmp=obs(2,isalive);
              ztmp=obs(3,isalive);
%%%%%              cosine=cos_fact(x0,y0,z0,transducer,flagg,xtmp,ytmp,ztmp,1);
					cosine =1;
					clear obs xtmp ytmp ztmp
%	      
% spherical spreading
%
%              r_attenu = TimeDel(isalive)/t_ref;
%
% incl. tissue attenuation 7.4.98 SH (0.5 due to intensity)
% and cosine-factor for soft baffle boundary conditions
%
              r_attenu = TimeDel(isalive)./(t_ref*cosine.*att.^(TimeDel(isalive)*0.5e6));

	      clear cosine;
%
% compute the response of the current burst only where it exists
%
              resp(isalive) = resp(isalive) + ...
                     r_attenu.\(Apodize(n)*w_pulse.*exp(jomega*t_vector));
%
% CW
%
            else
%
% find the actual time for the response computation
%
              t_vector = TimeDel - Time - TStFo;
% 
% cosine of angle of incidene:  (LO: 05.06.98)          
%
              obs=xyz2fpts(x,y,z);
%%%%              cosine=cos_fact(x0,y0,z0,transducer,flagg,obs(1,:),obs(2,:),obs(3,:),1);
						cosine = 1;
					clear obs
%	      
% spherical spreading
%
%              r_attenu = TimeDel/t_ref;
%
% incl. tissue attenuation 7.4.98 SH (0.5 due to intensity)
% and cosine-factor for soft baffle boundary conditions
%
              r_attenu = TimeDel./(t_ref*cosine.*att.^(TimeDel*0.5e6));

	      clear cosine;
%
% compute the response of the current burst only where it exists
%
              resp = resp + r_attenu.\(Apodize(n)*exp(jomega*t_vector));
%
% end of if
%
          end
%
% end of loop over elements and the element points
%
      end
%
% print message
%
    if UNIX,
	      
                fprintf('Loop %3.0f of %3.0f now at %4.0f of totally %4.0f computations\r',PNo,TLen,n,ElPt(2));
    else
		fprintf('Loop 		%3.0f of %3.0f now at %4.0f of %4.0f computations\n', ...
                        PNo,TLen,n,ElPt(2));
    end  


      
%
% compute max / min of response. Real and imaginary part for both.
%
      max_resp = [max(max_resp(1),max(real(resp))) ...
	          max(max_resp(2),max(imag(resp))) ];  
      min_resp = [min(min_resp(1),min(real(resp))) ...
                  min(min_resp(2),min(imag(resp))) ];
%	  
% put the response into a matrix and normalize
%
% added check of dimensions 23.01.98 SH
%


      if length(FieldSize)==2,
	tmp1 = FieldSize(1);
	tmp2 = FieldSize(2);
	tmp3 = 1;
	if option(1) == 'f' | option(1)== '3'      % Changes for 3D
	  resp = reshape(resp,tmp1,tmp2); 
	else
	  resp = reshape(resp,tmp1,tmp2);
     	  resp = resp'; % to have x-range columns and (y/z)-range rows
	end  

      else
%
%  Matlab 5
% 
        tmp1 = FieldSize(1);
	tmp2 = FieldSize(2);
        tmp3 = FieldSize(3);
        resp = reshape(resp,tmp1,tmp2,tmp3);      
      end


      if (flagg(2) == 1),
%
% rectangular array
%
          resp = resp./ (Np_az*Mp_el);
        else
%
% annular array
%
          resp = Ne_az*resp./Np_az;
      end
      
%
% save resp matrix to file for movie
%
      if option(1) == 'm' | option(1) =='f'   % Changed for 3d
          if (PNo < 10)
              eval(['Pict00',num2str(PNo),' = resp;'])
              eval(['save ',usr_resdir,delim,'Pict00',num2str(PNo),'.mat Pict00',num2str(PNo)])
            elseif ((PNo >= 10)&(PNo < 100))
              eval(['Pict0',num2str(PNo),' = resp;'])
              eval(['save ',usr_resdir,delim,'Pict0',num2str(PNo),'.mat Pict0',num2str(PNo)])
            elseif ((PNo >= 100)&(PNo < 1000))
              eval(['Pict',num2str(PNo),' = resp;'])
              eval(['save ',usr_resdir,delim,'Pict',num2str(PNo),'.mat Pict',num2str(PNo)])
          end
      end
%
% end of loop over time-references
%
  end

  return
