%----------------------------------------------------------------
% Routine     : peplcont.m (PE Plot Contour) 
%
% Description : Plots the results from a PE-analysis in the 
%               'plotfig' window as a contour plot.               
%               
% Language    : Matlab V4.1
% Written by  : Vingmed sound A/S, Trond Kleveland 
%
% Version no. : 1.0 TKL 17.09.93 First version
%             : 1.1 TKL 22.09.93 Removed analysis
%             : 1.2 TKL 23.09.93 Added Time - analysis, 
%             : 1.3 SH  19.11.93 Added Iso beamwidth contour
%             : 1.4 TKL 22.11.93 Short filenames
%             : 1.5 TKL 24.11.93 Added yz-plane to analysis
%             : 1.6  SH 02.12.93 Added flag as input variable
%             : 1.7 TKL 13.12.93 Added xy-plane to analysis
%             : 1.8  SH  4. 2.94 Added reflection about z/t-axis for beamwidth plots
%             : 1.9  SH  4. 3.94 Corrected small error in reflection routine
%             : 2.0 BJE 17.10.94 Changed function call, set plotOption
%             : 2.1  SH 20.01.95 Other initialization of iso-plot
%             : 2.2 BJE 26.04.95 Changed function call
%             : 2.3 SH  10.05.96 Added subplot command to initialize graph window
%               2.4 SH  04.09.96 Contour of 2D movie simulations; 2 more variables
%                                in call, check normalization in 'iso' to
%                                avoid x/0.
%             : 2.5 AA  05.09.96 Changed normalization check for 'iso' to
%                                only work when "option(1) == 'm'" 
%               2.6 SH  12.11.96 More robust input using 'vinput'
%                                transfer of contour settings to/from file
%                                improved check for y/t reflection of data
%               2.7 SH  22.05.97 Can now do 'iso' for pulse data
%                                Do not save infinite contours and labels
%               2.8 SH  30.05.97 Matlab 5: removed statement that gave warnings
%                                (test for isempty after input statement)
%                                abs(max) for iso - plot
%               2.9 SH  23.01.98 save in matlab 4 format

%
% Called by   : usimcnf
% Calling     : cleanscr, petxt, vinput 
%----------------------------------------------------------------

function peplcont(resp, excitation, media, transducer, option, flagg, ...
      x, y, z, t, plotfig, plotfigOrigHandle, usr_resdir, observasjon, separator)
%
% INITIALIZATION
%
  clc
  cleanscr(plotfig,plotfigOrigHandle);
  figure(plotfig);
  subplot(1, 1, 1)

  
  
  MeshCont = 'Cont';
  Rf_Envelope = 'e';   

%
% set plot option : lin/log/iso
%
  disp('  ')
  disp('Set plot option : ')
  disp('  ')
  
  plotOption = input('-> Beamwidth / Linear / Logarithmic [iso/lin/log] ? ','s');

  if isempty(plotOption) | (all(plotOption ~= 'lin') & all(plotOption ~= 'log'))
      plotOption = 'iso';       % default
  end

  disp('  ')
% 
% check for movie
%
 nplots = 1;
 fid = 1;
 if option(1) == 'm'
      delta_t=1/(1e3*observasjon(15)*excitation(14));	% calc from c and # obs
      nplots = 1+(observasjon(8)-observasjon(4))/delta_t;
      fprintf(fid,'Finding contour of maximum of %3.0f snapshots\n\n', nplots);
%
% loop over nplots
%
  for PNo = 1 : nplots 
      
%
% load resp from file for movie
%
d = separator;
   if (PNo < 10)
     eval(['load ',usr_resdir,d,'Pict00',num2str(PNo),'.mat'])
     eval(['tempresp = Pict00',num2str(PNo),';'])
     if (PNo == 1) 
       resp = abs(tempresp); 
     end
     eval(['clear Pict00',num2str(PNo),';']);
   elseif ((PNo >= 10)&(PNo < 100))
     eval(['load ',usr_resdir,d,'Pict0',num2str(PNo),'.mat'])
     eval(['tempresp = Pict0',num2str(PNo),';'])
     eval(['clear Pict0',num2str(PNo),';']);
   elseif ((PNo >= 100)&(PNo < 1000))
     eval(['load ',usr_resdir,d,'Pict',num2str(PNo),'.mat'])
     eval(['tempresp = Pict',num2str(PNo),';'])
     eval(['clear Pict',num2str(PNo),';']);
   end
   resp = max(resp,abs(tempresp));
 end 
end

  
  
%
% set the text variables
%
  [Xtxt,Ytxt,Ztxt,Ttxt1,Ttxt2,Ttxt3] = ...
      petxt(excitation,media,transducer,option,flagg,z,t,Rf_Envelope,plotOption,MeshCont);
%
% axis, depending on distance or time analysis
%
  mirror = 0;
  if all(option(2:3) == 'xz')         
      Xx = x(1,:)*1e3;
      Zz = z(:,1)'*1e3;
%     mirror =  ~all(Xx~=0);
      mirror = all(max(Xx')==0) | all(min(Xx')==0);
    elseif all(option(2:3) == 'xy') 
      Xx = x(1,:)*1e3;
      Zz = y(:,1)'*1e3;
    elseif all(option(2:3) == 'yz')
      Xx = y(1,:)*1e3;
      Zz = z(:,1)'*1e3;
      mirror = all(max(Xx')==0) | all(min(Xx')==0);
    elseif all(option(2:3) == 'xt')
      Xx = x(1,:)*1e3;
      Zz = t(:,1)'*1e6;
      mirror = all(max(Xx')==0) | all(min(Xx')==0);
  end
  
  if mirror,
%
% this question is only asked if the plot is (x,z), (y,z), or (x,t) and
% 0 is contained in the first axis.
%
      reflect = input('-> Reflect plot about z/t-axis [y/n] ? ','s');   
      if isempty(reflect)
          reflect = 'y';
      end
      if reflect == 'y',
          LXx = length(Xx);
          respud = flipud(resp);
          if (max(Xx) > 0),
              Xx = [-fliplr(Xx(2:LXx)), Xx];
              resp = [respud(1:LXx-1,:)', resp']';
            else
              Xx = [Xx, -fliplr(Xx(1:LXx-1)) ];
              
              resp = [resp', respud(2:LXx,:)']';
          end
          
      end
  end
  
%
% Find the envelope of the signal
%

  if all(plotOption == 'lin') 
      
      resp=abs(resp);
      
    elseif all(plotOption == 'log') 
      
      resp=20*log10(abs(resp)/transducer(2) + eps);
      
    elseif all(plotOption == 'iso')
      
      [rows, cols] = size(resp);
      
      for depth = 1:cols
%
% normalize so that maximum at all depths is 0 dB
%
          beam_max = abs(max(resp(:,depth)));
% 22.5.97 SH	  if (beam_max <= 0 & option(1) == 'm'),
          if (beam_max > 0)
	    resp(:,depth) = resp(:,depth)/beam_max;
	  end
	end
      resp=20*log10(abs(resp) + eps);
      
    else
      
      disp('ERROR detected in peplcont')
      disp('  ')
      return
      
  end
%
% find the maximum of the response
%
  top=max(resp(:));
  top=floor(top*10)/10;
%
% get past values of contours
%
  if exist([usr_resdir,separator,'contours.mat'])
     eval(['load ',usr_resdir, separator,'contours.mat']);
  end

  if ~exist('cont_prev')
       cont_prev = [-6, -12, -18]; 	% dB
  end
  
  if all(plotOption == 'lin')
      cont = top * 10.^(cont_prev/20);
    else % 'log' or 'iso'
      cont = top + cont_prev;
  end
  clc
  disp('  ')
  if all(plotOption == 'lin')
      tmp=['     Maximum in this plot is ',num2str(top)];
    else
      tmp=['     Maximum in this plot is ',num2str(top),' [dB] '];
  end
  disp(tmp)
  disp('   ');
  disp('     Contours are placed at the following levels')
  disp('  ')
  for k=1:length(cont)
      fprintf('     %6.2f',cont(k))
  end             
  
  disp(' ')
  mod_contour = input('-> Modify contours [n/y] ? ','s');
  if isempty(mod_contour)
      mod_contour = 'n';
  end
  
  if mod_contour == 'y' 
      tmp = input('-> Specify number of contours  <CR> = no change : ');
      if isempty(tmp)
          tmp=length(cont);
      end
      if tmp > length(cont);
          cont(tmp) = 0;
        elseif tmp < length(cont);
          cont = cont(1:tmp);
      end
  end
  
  while mod_contour == 'y'
      disp('  ')
      tmp = vinput('element number to change : ',1,length(cont),1);
      cont(tmp) = input('-> Enter new value (remember sign) : ');
      mod_contour = input('-> More [n/y] ? ','s');
      if isempty(mod_contour)
          mod_contour = 'n';
      end
      clc
      if mod_contour == 'y'
          disp('  ')
          disp('     Contours are placed at the following levels')
          disp('  ')
          for k=1:length(cont)
              fprintf('     %6.2f',cont(k))
          end         
      end
  end
  
  clc

  if ~exist('n_label')
     n_label = length(cont);
  end  
  label = cont(1:n_label);
  
  disp('  ')
  disp('     Contour labels : ')
  disp(' ')
  for k=1:length(label)
      fprintf('     %6.2f',label(k))
  end             
  
  disp('  ')
  mod_contour = input('-> Modify contour labels [n/y] ? ','s');
  if isempty(mod_contour)
      mod_contour = 'n';
  end
  
  if mod_contour == 'y' 
      n_label = vinput('number of labels, <0 = mouse input',-1,length(cont),n_label);
      mod_contour = 'n';
      if n_label > 0, 
        if n_label < length(label);
          label = label(1:n_label);
        end
        mod_contour = input('-> Modify any labels [n/y] ? ','s');
        if isempty(mod_contour)
          mod_contour = 'n';
        end
      end
  end
  
  while mod_contour == 'y'
      disp('  ')
      tmp = vinput('element number to change : ',1,length(cont),1);
      label(tmp) = input('-> Specify new value (remember sign) : ');
      mod_contour = input('-> More [n/y] ? ','s');
      if isempty(mod_contour)
          mod_contour = 'n';
      end
      clc
      if mod_contour == 'y'
          disp('     Contour labels : ')
          disp('  ')
          for k=1:length(label)
              fprintf('     %6.2f',label(k))
          end         
      end
  end
%
% store relative contour and label settings in dB
%
  if all(plotOption == 'lin')
      cont_prev = 20*log10(cont/top);
  else
      cont_prev = cont - top;
  end
  if all(finite(cont_prev)),
      vers = version;
      if vers(1)=='5'
       eval(['save ',usr_resdir, separator,'contours.mat cont_prev n_label -v4']);
      else
	       eval(['save ',usr_resdir, separator,'contours.mat cont_prev n_label']);
      end	 
  end
%
% get current axes position modify it and make up another axes for text
%
  handle1 = gca;
  v1 = get(handle1,'Position');
  v1(4)=v1(4)-0.1;
  set(handle1,'Position',v1)
  
  v2    = v1;
  v2(1) = v2(1) - 0.1;
  v2(2) = v2(2) + v2(4) + 0.05;
  v2(4) = 0.1;
  handle2 = axes('Position',v2);
  axis('off')
%
% Plot the computed response in a contour plot
%
  axes(handle1)

  cla
  cs=contour(Zz,Xx,resp,cont);
%	surfc(Zz,Xx,resp)
  if n_label > 0,
     clabel(cs,label);
  elseif n_label < 0,
     clabel(cs,'manual');
  end

  grid
  xlabel(Xtxt);
  ylabel(Ytxt);
  
  axes(handle2)
  cla
  text(0 , 1.0 ,Ttxt1);
  text(0 , 0.5 ,Ttxt2);
  text(0 , 0.0 ,Ttxt3);
  
  fprintf('\n\nFinished!\n');
  
  
