%------------------------------------------------------------------------
% Routine     : chmedia.m
%
% Description : Callback to change media flag menu. Converts the media
%               variable from 2D format to 3D format or vice-versa if
%               necessary.
%
% Language    : Matlab 4.1
% Written by  : Frode Teigen (IBT) 
%
% Version no. : 3.0 FT 20.03.94 First version
%               3.1 FT 22.03.94 Corrected minor bug
%
% Called by   : usimcnf
% Calling     : 
%------------------------------------------------------------------------

function [flagg,media] = chmedia(flagg,media,transducer,newvalue);

if newvalue==2 & (flagg(3)==1 & media(1,8)~=3)
  flagg(3) = 2;
  media(1,8) = 2;
elseif newvalue==2 & (flagg(3)==3 | media(1,8)==3)
  flagg(3) = 2;
  media(1,8) = 2;
  disp(' Conversion from 3D to 2D format ...');
  ind = find(media(:,3)==2);
  media(ind,6:7) = media(ind,7:8);
  media(2:size(media,1),1) = media(2:size(media,1),1) + transducer(15);
  if transducer(15)~=0
    fprintf(1,' Added a transducer offset of %4.2fmm to the z-values \n',...
	transducer(15)*1e3);
    disp(' Done!');
  end
elseif newvalue==3 & (flagg(3)==1 & media(1,8)~=2)
  flagg(3) = 3;
  media(1,8) = 3;
elseif newvalue==3 & (flagg(3)==2 | media(1,8)==2)
  flagg(3) = 3;
  media(1,8) = 3;
  disp(' Conversion from 2D to 3D format ...');
  ind = find(media(:,3)==2);
  media(ind,5:8) = media(ind,4:7);
  ind = find(media(:,3)==4);
  if ind ~=[]
    disp(' WARNING! Function class 4 is not defined for 3D media - set to 1');
    media(ind,3)=ones(size(ind));
  end
  ind = find(media(:,3)==5);
  if ind ~=[]
    disp(' WARNING! Function class 5 is not defined for 3D media - set to 1');
    media(ind,3)=ones(size(ind));
  end
  media(2:size(media,1),1) = media(2:size(media,1),1) - transducer(15);
  if transducer(15)~=0
    fprintf(1,[' Subtracted a transducer offset of %4.2fmm from ',... 
	'the z-values \n'],transducer(15)*1e3);
    disp(' Done!');
  end
end

