%------------------------------------------------------------------------
% Routine     : rhp2xyz
%
% Description : coordinat-transformation from spherical to rectangular
%                   r=Radial, h=tHeta, p=Phi 
%                   Special feature is that r is allowed to be Inf and NaN,
%                   in such cases x = theta, y = phi and z = Inf
%
% Language    : Matlab 4.1
% Written by  : Vebjorn Berre, IBT
%
% Version no. : 1.0 VEB 01.04.93
% Version no. : 1.1 TKL 17.09.93 changed from r==Inf,NaN -> x=theta y=phi to
%                                r==Inf,NaN -> x=0 y=0
% Called by   : many
% Calling     : none
%------------------------------------------------------------------------

function [x,y,z] = rhp2xyz(r,h,p)

  x=r.*sin(p).*cos(h);
  y=r.*sin(p).*sin(h);
  z=r.*cos(p);

  % detect r=Inf and r=NaN and use the convention x=0 and y=0 for
  % such cases:
  
  ind=find(isnan(r));
  if ~isempty(ind)
    x(ind) = zeros(size(ind));
    y(ind) = zeros(size(ind));
    z(ind) = Inf*ones(size(ind));
  end

  ind=find(isinf(r));
  if ~isempty(ind)
    x(ind) = zeros(size(ind));
    y(ind) = zeros(size(ind));
    z(ind) = Inf*ones(size(ind));
  end

