%------------------------------------------------------------------------------
% Function    : v = vinput(str,lower,upper,default)
%
% Description : safe value input. str is a text-string describing v. The value 
%               satisfies lower <= v <= upper and v = default for <CR>.
%
%
% Language    : Matlab 4.2
% Written by  : Bjrnar Elgetun, Ifi-UiO
%
% Version no. : 1.0 BJE 20.11.95 first version
%
% Called by   : *
%------------------------------------------------------------------------------

function v = vinput(str,lower,upper,default)

%
% check arguments
%
  if (nargin < 4)
      error('syntax: v=vinput(str,lower,upper,default)');
  end

%
% get input
%
  v=input(['-> Enter ' str ' [' num2str(default) '] : ']);

%
% check value
%
  if isempty(v)
      v=default;
  end

  while (v < lower | v > upper)
      v=input(['-> Enter ' str ' between ' num2str(lower) ...
	       ' and ' num2str(upper) ' [' num2str(default) '] : ']);
      if isempty(v)
	  v=default;
      end
  end

            
      