%------------------------------------------------------------------------
% Routine     : xyz2rhp
%
% Description : transformation from rectangular to spherical coordinates
%               r > 0, 0 <= h < 2*pi, 0 <= p <= pi
%               r=Radial, h=tHeta, p=Phi 
%               Special feature is that when z = Inf;
%               in such cases theta = x , phi = y  and r = Inf
%
% Language    : Matlab 4.1
% Written by  : Vebjorn Berre, IBT
%
% Version no  : 1.0 VEB 28.04.93 first version
% Version no. : 1.1 TKL 30.07.93 check for r~=0, check for (x,y)=(0,0)->p=0
% Version no. : 1.2 TKL 17.09.93 added check for x or y or z == Inf
%                                changed from z==Inf -> r=Inf h=x p=y to
%                                x==Inf -> r=Inf h=0    p=pi/2 
%                                y==Inf -> r=Inf h=pi/2 p=pi/2 
%                                z==Inf -> r=Inf h=0    p=0    
%
% Called by   : many
% Calling     : none
%------------------------------------------------------------------------

function [r,h,p] = xyz2rhp(x,y,z)


r=sqrt(x.^2+y.^2+z.^2);

p=zeros(size(r));

ind=find(r~=0);
if ~isempty(ind)
  p(ind)=acos(z(ind)./r(ind));
end

h=zeros(size(r));

ind=find(x<0);
h(ind)=atan(y(ind)./x(ind))+pi;
ind=find(x>0);
h(ind)=atan(y(ind)./x(ind));
ind=find(x==0 & y>0);
h(ind)=pi/2*ones(size(ind));
ind=find(x==0 & y<0);
h(ind)=3*pi/2*ones(size(ind));
ind=find(x==0 & y==0);
h(ind)=zeros(size(ind));
p(ind)=zeros(size(ind));

% h should be positive 
ind=find(h<0);
h(ind)=h(ind)+2*pi;
ind=find(h>=2*pi);
if ~isempty(ind)
  disp(' Theta >= 2*pi in conversion from xyz2rhp ')
end

ind=find(isinf(x));
if ~isempty(ind)
  r(ind)=inf*ones(size(ind));
  h(ind)=zeros(size(ind));
  p(ind)=pi/2*ones(size(ind));
end

ind=find(isinf(y));
if ~isempty(ind)
  r(ind)=inf*ones(size(ind));
  h(ind)=pi/2*ones(size(ind));
  p(ind)=pi/2*ones(size(ind));
end

ind=find(isinf(z));
if ~isempty(ind)
  r(ind)=inf*ones(size(ind));
  h(ind)=zeros(size(ind));
  p(ind)=zeros(size(ind));
end








