%---------------------------------------------------------------------------
% Routine     : usiminit.m
%
% Description : initialization of MATLAB for ULTRASIM
% 
% Language    : MATLAB 4.0
% Written by  : Vebjorn Berre 27/10-92
%
% Version no. : 3.0
%             : 3.1 VEB 06.05.93
%             : 3.2 TKL 14.07.93 Added flagg(5)=1 as a default
%             : 3.3 SH  20.07.93 Changed order of calls   
%             : 3.4 FT  23.08.93 Added default values for excitation(11:13)
%             : 3.5 TKL 03.09.93 Added comments, and analysis variable
%             : 3.6 TKL 22.09.93 Removed analysis variable
%             : 3.7 FT  27.09.93 Added path to aberration3D
%             : 3.8 SH  17.11.93 Initialized obervasjon(15), media(:,8:11)
%             : 3.9 SH   6.12.93 Changed default array to 1D  
%             : 4.0 FT  11.02.94 Added default values for excitation(14:21)
%                                Removed path to cwnear
%             : 4.1 SH  25.02.94 Added path to /coarray
%               4.2 FT  28.02.94 Added layerflag
%               4.3 FT  20.03.94 Transducer(13,14)=0, removed 'linjeparametre'
%               4.4 SH   3.08.94 Moved path for 'bp' due to naming conflict with 
%                                routine 'quantize' in simulink ver 1.3b
%               4.5 SH  24.08.94 Made runnable on DOS in addition to UNIX
%               4.6 FT  28.09.94 Added default of flagg(6)
%               4.7 SH  16.11.94 Computer-independent setup   
%               4.8 SH   6.12.94 Changed call rectangular to rectangu
%               4.9 LO  31.03.95 Default comment added
%               5.0 SH  14.04.95 Removed trailing path separator from cnf_mech ...
%               5.1 BJE 01.05.95 Initialization WITHOUT default values, removed
%                                layerflag, moved init of d (path separator) to
%                                ultrasim.m, removed comments, added printercmd
%                                added path to \optimize
%               5.2 SH  30.05.95 Added doc_command for setting documentation tool
%               5.3 SH  15.07.96 path to 1point5 directory
%               5.4 SH  01.10.96 centers=[]; added
%               5.5 SH/KE 3.2.97 initialized visualize variable
%               5.6 NAA 18.02.97 Path to 'genetic' included
%               5.7 SH  04.06.97 Changed resetting in beginning
%                                Corrected for matlab 5                    
%               5.8 AA  17.07.97 Path to 'annealing' included
%                   SH  07.07.97 ... shortened to 'anneal'
%               5.9 SH   7.04.98 New welcome message + acroread option
%               6.0 AA  17.04.01 Path to 'farfield' included
%
% Called by   : ultrasim
% Calling     : apobserv, rectangu, userusim
%---------------------------------------------------------------------------

%---------------------------------------------------------------------------
%     CLEARING/ RESET OF MATLAB SESSION
%---------------------------------------------------------------------------

clc;

%
%---------------------------------------------------------------------------
%     SETTING OF MATLABPATH FOR THE ULTRASIM SESSION
%---------------------------------------------------------------------------
%
% when installing ULTRASIM please edit ULTRASIMHOME
%
%
% Informatikk, UiO:
%
   ULTRASIMHOME='/local/matlab/toolbox/ultrasim';

%
% PC
%
%   ULTRASIMHOME='c:\matlab\toolbox\ultrasim'; 


%---------------------------------------------------------------------------
%     LOCAL PRINTER COMMAND
%---------------------------------------------------------------------------

printercmd='!print';
%
%  printercmd='!aprint';      
%
%---------------------------------------------------------------------------
%     LOCAL DOCUMENTATION COMMAND (UNIX ONLY)
%---------------------------------------------------------------------------
%
%   doc_command = '!xdvi';
   doc_command ='!acroread';
%
%  doc_command ='!ghostview';

%
% take care of the "original" path before starting the usim session
%
oldpath=path;

%
% moved here from ultrasim.m 27.05.97 (for matlab5)
%
%
% determine computer-dependent path separator
%

cc=computer;
if (cc(1:2) == 'PC'),
    separator = '\';                          %'
  else
    separator = '/';
end

%
% New setting of path is different on PC and UNIX
%
if separator=='/'               % UNIX
    separator2=':';
  else
    separator2=';';
end



%
% configuration % modified for matlab 5; 27.05.97
%
newpath=[ULTRASIMHOME,separator,'config',separator2];
newpath=[newpath,ULTRASIMHOME,separator,'1point5',separator2];
newpath=[newpath,ULTRASIMHOME,separator,'view',separator2];
newpath=[newpath,ULTRASIMHOME,separator,'list',separator2];
%
% plot-tool
%
newpath=[newpath,ULTRASIMHOME,separator,'plot',separator2];

%
% general ultrasim / matlab - tools
%
newpath=[newpath,ULTRASIMHOME,separator,'toolbox',separator2];
newpath=[newpath,ULTRASIMHOME,separator,'txt',separator2];

%
% annular design
% 
newpath=[newpath,ULTRASIMHOME,separator,'annulus',separator2];

%
% beampattern
%
newpath=[newpath,ULTRASIMHOME,separator,'bp',separator2];

%
% pe - pulsed excitation
%
newpath=[newpath,ULTRASIMHOME,separator,'pe',separator2];

%
% coarray - coarray calculation
%
newpath=[newpath,ULTRASIMHOME,separator,'coarray',separator2];

%
% farfield - array response
% 
newpath=[newpath,ULTRASIMHOME,separator,'farfield',separator2];
%
% ----
%
% phase aberrations
% names shortened 24.08.94 SH:
newpath=[newpath,ULTRASIMHOME,separator,'aberrati',separator2];
newpath=[newpath,ULTRASIMHOME,separator,'aberra3d',separator2];
%
% ----
%
% optimization
% 
 newpath=[newpath,ULTRASIMHOME,separator,'optimize',separator2];

%
% genetic algorithms
% 
newpath=[newpath,ULTRASIMHOME,separator,'genetic',separator2];

%
% simulated annealing algorithms
% 
newpath=[newpath,ULTRASIMHOME,separator,'anneal',separator2];

% ----

%
% finally, set newpath and clear
%
path(newpath,path);
clear newpath;
clear separator2;


%---------------------------------------------------------------------------
%     CONFIGURATION DIRECTORIES (these follow the ULTRASIM-program)
%---------------------------------------------------------------------------
%
%
% shortened path names to 8 characters, SH 24.08.94,
% removed trailing separator SH 14.04.95:
Mech = [ULTRASIMHOME,separator,'cnf_mech'];
Elec = [ULTRASIMHOME,separator,'cnf_elec'];


%---------------------------------------------------------------------------
%        SETUPS DEFINED BY USER 
%---------------------------------------------------------------------------

path(path,[ULTRASIMHOME,separator,'user'])

%
% initialization file (check if the user has defined his own init-file)
% be aware that the file MUST be named userusim.m and be placed in a 
% directory which is included ONLY in this users MATLABPATH.
%
if exist('userusim') == 2
    userusim;
  else
    usr_resdir = pwd;
end  

%
% configuration directories - please PLACE your definitions into userusim.m
%


%---------------------------------------------------------------------------
%           TYPE VERSION OF INSTALLATION
%---------------------------------------------------------------------------

disp(' ')
%ver(ULTRASIMHOME)
ver('ultrasim')
disp(' ')
disp('Department of Informatics, University of Oslo')
disp(' ')
disp('This program may be freely copied and improved,')
disp('If you find the program useful, or you have improvements to contribute,')
disp('please send a message to ultrasim@ifi.uio.no')
disp('Program web-site is www.ifi.uio.no/~ultrasim')

disp(' ')
disp('Press Enter to proceed')
pause

%---------------------------------------------------------------------------
%   DEFAULT VALUES / INITIAL PARAMETER VALUES
%---------------------------------------------------------------------------


excitation=[ 3.5e6 0 0 100e-3 0 0 0 0.1 0 0  1e8 0  0  1540 0  0  0  0  0  0  0];

observasjon=zeros(1,15);

%
%        zn       cn    fcn                              Z   alpha
%                          #1       #2       #3  #4  #5          beta
media = [0        1540  2  0        0        0   0   0   0   0   1
         0.00945  1880  2  0.00945  0.00945 -1   0   0   0   0   1
         0.00953  1540  2  0.00953  0.00953 -1   0   0   0   0   1
         0.00953  1440  1 -0.000   -0.00     0   0   0   0   0   1
         0.03000  1580  1  0.000   -0.00     0   0   0   0   0   1];

transducer=zeros(1,18);

flagg=[1 1 1 1 1 0];            

option='2xz';

x=[]; y=[]; z=[]; t=[]; 
elem_pts=[];
centers=[];

abrflagg=[2,0,0,1,1,1,2,1,0];

elecdelr=0;
elecdelt=0;

comment=' ';

pvec=[]; 
plength=[];

phase_err_ud=[]; 
amp_ud=[];

array_resp=[]; 
max_resp=[]; 
min_resp=[];
%
% 3.2.97:
% 
% e/r: envelope/rf
% lin/log/iso
% hot: colormap
% total of 10 characters

visualize = 'elinhot   ';



