%------------------------------------------------------------------------
% Function    : vwctrl(ACTION,figurep)
%
%               ACTION    'init'
%                         'update'
%                         'dismiss'
%	
% Description : place sliders with dismiss button which controls
%               view in current axes
%
% Language    : Matlab 4.2
% Written by  : Bjrnar Elgetun, Ifi-UiO
%
% Version no. : 1.0 BJE 19.05.95 first version 
%               1.1 BJE 07.07.95 update view if control already exists
%
% Called by   : plotw2d, optw2d
% Calling     : vwctrl
%------------------------------------------------------------------------

function vwctrl(ACTION,figurep); 
  

% --------------------------------------
% ACTION 'init' - if not already exists
% --------------------------------------

  if strcmp(ACTION,'init') 

      if isempty(findobj(figurep,'string','bjevwctrl'))
          
          az=37.5;	% default view(az,el)
          el=30;	
          
          DW=1/40;	% delta width
          LH=1/30; 	% line height	(30 lines)
          
% azimuth slider
          
          ASX=30*DW;	% slider offset
          ASY=0;	
          ASW=9*DW;	% slider width
          ASH=LH;	% slider height
          
% elevation slider
          
          ESX=39*DW;	% slider offset
          ESY=LH;	
          ESW=DW;	% slider width
          ESH=9*LH;	% slider height
          
%
% 2 sliders
%
          azp=uicontrol('style','slider','units','normalized', ...
              'position',[ ASX ASY ASW ASH ], ...
              'min',0,'max',90,'value',az, ...
              'string','bjevwctrl', ...
              'callback','vwctrl(''update'',gcf);');
          
          elp=uicontrol('style','slider','units','normalized', ...
              'position',[ ESX ESY ESW ESH ], ...
              'min',0,'max',90,'value',el, ...
              'callback','vwctrl(''update'',gcf);');
          
%
% dismiss button
%
          btnp=uicontrol('style','push','units','normalized', ...
              'position',[ ESX ASY ESW ASH ], ...
              'callback','vwctrl(''dismiss'',gcf);');
          
%
% append pointers in figures userdata
%
          origdata=get(figurep,'userdata');
          plist=[origdata azp elp btnp];
          set(figurep,'userdata',plist);
          vwctrl('update',figurep);

	else

%
% control already exists
%
	  vwctrl('update',figurep);

      end


% -----------------
% ACTION 'update'
% -----------------

    elseif strcmp(ACTION,'update')
      
      if ~isempty(findobj(figurep,'string','bjevwctrl'))
          tmp=get(figurep,'userdata');		   
          azp=tmp(length(tmp)-2);
          elp=tmp(length(tmp)-1);
      
%
% update view
%
          az=get(azp,'value');
          el=get(elp,'value');
          view(az,el);
      end
      

% -----------------
% ACTION 'dismiss'
% -----------------

    elseif strcmp(ACTION,'dismiss')
      
      if ~isempty(findobj(figurep,'string','bjevwctrl'))
          tmp=get(figurep,'userdata');		   
      
          azp=tmp(length(tmp)-2);
          elp=tmp(length(tmp)-1);
          btnp=tmp(length(tmp) );
      
%
% delete controls
%
          delete(azp);
          delete(elp);
          delete(btnp);
      
%
% delete pointers stored in userdata 
%      
          set(figurep,'userdata',tmp(1:length(tmp)-3));
      end
      
  end





