%------------------------------------------------------------------------
% Function    : vwctrl2(ACTION,figurep,axes1p,axes2p)
%
%               ACTION    'init'
%                         'update'
%                         'dismiss'
%	
% Description : place sliders with dismiss button which controls
%               view in axes1 and axes2 of figure
%
% Language    : Matlab 4.2
% Written by  : Bjrnar Elgetun, Ifi-UiO
%
% Version no. : 1.0 BJE 07.07.95 first version 
%
% Called by   : resp2d
% Calling     : vwctrl2
%------------------------------------------------------------------------

function vwctrl2(ACTION,figurep,axes1p,axes2p); 
  

% --------------------------------------
% ACTION 'init' - if not already exists
% --------------------------------------

  if strcmp(ACTION,'init') 

      if isempty(findobj(figurep,'string','bjevwctrl2'))
          
          az=37.5;	% default view(az,el)
          el=30;	
          
          DW=1/40;	% delta width
          LH=1/30; 	% line height	(30 lines)
          
% azimuth slider
          
          ASX=30*DW;	% slider offset
          ASY=0;	
          ASW=9*DW;	% slider width
          ASH=LH;	% slider height
          
% elevation slider
          
          ESX=39*DW;	% slider offset
          ESY=LH;	
          ESW=DW;	% slider width
          ESH=9*LH;	% slider height
          
%
% 2 sliders
%
          azp=uicontrol('style','slider','units','normalized', ...
              'position',[ ASX ASY ASW ASH ], ...
              'min',0,'max',90,'value',az, ...
              'string','bjevwctrl2', ...
              'callback','vwctrl2(''update'',gcf);');
          
          elp=uicontrol('style','slider','units','normalized', ...
              'position',[ ESX ESY ESW ESH ], ...
              'min',0,'max',90,'value',el, ...
              'callback','vwctrl2(''update'',gcf);');
          
%
% dismiss button
%
          btnp=uicontrol('style','push','units','normalized', ...
              'position',[ ESX ASY ESW ASH ], ...
              'callback','vwctrl2(''dismiss'',gcf);');
          
%
% append pointers in figures userdata
%
          origdata=get(figurep,'userdata');
          plist=[origdata azp elp btnp axes1p axes2p];
          set(figurep,'userdata',plist);
          vwctrl2('update',figurep);

	else

%
% control already exists
%
	  vwctrl2('update',figurep);

      end


% -----------------
% ACTION 'update'
% -----------------

    elseif strcmp(ACTION,'update')
      
      if ~isempty(findobj(figurep,'string','bjevwctrl2'))
          tmp=get(figurep,'userdata');		   
          azp=tmp(length(tmp)-4);
          elp=tmp(length(tmp)-3);
          axes1p=tmp(length(tmp)-1);
          axes2p=tmp(length(tmp));
      
%
% update view
%
          az=get(azp,'value');
          el=get(elp,'value');
          axes(axes1p);
          view(az,el);
          axes(axes2p);
          view(az,el);
      end
      

% -----------------
% ACTION 'dismiss'
% -----------------

    elseif strcmp(ACTION,'dismiss')
      
      if ~isempty(findobj(figurep,'string','bjevwctrl2'))
          tmp=get(figurep,'userdata');		   
      
          azp=tmp(length(tmp)-4);
          elp=tmp(length(tmp)-3);
          btnp=tmp(length(tmp)-2);
      
%
% delete controls
%
          delete(azp);
          delete(elp);
          delete(btnp);
      
%
% delete pointers stored in userdata 
%      
          set(figurep,'userdata',tmp(1:length(tmp)-5));
      end
      
  end

