%------------------------------------------------------------------------
% Routine         : vwdelay.m
%
% Description     : Calculation and view of steering and focusing delays.
%
% Language        : MATLAB 4.0
% Written by      : Vebjorn Berre (IBT)
%
% Version no.     : 3.0 VEB 23.04.93
%                   3.1 FT  28.09.94 added [mm] to x-/y-label
%                   3.2 SH  03.06.96 centers in call to focus.m
%
% Called by       : usimcnf
%------------------------------------------------------------------------
function delta_t_rx=vwdelay(transducer,excitation,media,elem_pts,centers,flagg,show)

% show==1 -> plot exact delays
% show==2 -> plot quantization errors
% show==3 -> plot phase-center


c=media(1,2);
N=length(elem_pts(1,:));
Fs=excitation(11);
intfact=excitation(12);

%          FOCUSING DELAYS
%---------------------------------------------------------------------------
% calculate and plot exact focusing delays
% input  : excitation, media, transducer, elem_pts, flagg
% output : delta_t_rx

[exact_rx,center] = focus(excitation,c,transducer,elem_pts,centers,flagg);



%
% quantize and plot the time delays to accuracy qt
% (only if interpolation is off)

[delta_t_rx] = quantize(excitation,exact_rx);


% plot phase-centers:
if show==3
  if flagg(2)==1
    subplot(3,1,1)
    plot(1000*center(1,:), 1000*center(2,:),'*')
    xlabel('x [mm]')
    ylabel('y [mm]')
    title('Phase centers of elements')
    grid
    
    subplot(3,1,2)
    plot(1000*center(2,:), 1000*center(3,:),'*')
    xlabel('y [mm]')
    ylabel('z [mm]') 
    grid
    
    subplot(3,1,3)
    plot(1000*center(1,:), 1000*center(3,:),'*')
    xlabel('x [mm]')
    ylabel('z [mm]') 
    grid
  elseif flagg(2)==3
    subplot(1,1,1)
    plot(1000*center(1,:), 1000*center(2,:),'*')
    xlabel('sqrt(x^2+y^2) [mm]')
    ylabel('z [mm]')
    title('Phase centers of elements')
    grid
  end
end



if show==1

  subplot(2,2,1),
  plotx0(elem_pts(2,:),1000*elem_pts(1,:),exact_rx*1e6)
  xlabel('x [mm]')
  ylabel('microseconds')

 if (transducer(7) >= 3),  % 2-Dimensional plot possible
  subplot(2,2,3),
  plotx0(elem_pts(1,:),1000*elem_pts(2,:),exact_rx*1e6)
  xlabel('y [mm]')
  ylabel('microseconds')

  subplot(1,2,2),
  vw(1000*elem_pts(1,:),1000*elem_pts(2,:),exact_rx*1e6,flagg(2));
  xlabel('x [mm]')
  ylabel('y [mm]')
  zlabel('microseconds')
  title('Exact delays')
 end 
end  

if show==2
  if (transducer(7) > 1), 
    disp('WARNING: This plot may be meaningless since the array is not 1-dimensional')
  end
  subplot(3,1,1)
  plot((0:N-1),(exact_rx)*1e6)
  grid
  title(['Exact time delay']);
  ylabel('microseconds')
  xlabel('Array element')

  subplot(3,1,2),
  plot((0:N-1),(delta_t_rx)*1e6)
  grid
  title(['Quant. time delay']);
  ylabel('microseconds')
  xlabel('Array element')

  
  %  plot delay quantization error
  %  
  subplot(3,1,3)
  plot((0:N-1),(exact_rx-delta_t_rx)*Fs*intfact)
%  axis([0, N-1, -0.5, 0.5]);
  grid
  title(['Time delay quantization error - ',quanttxt(excitation)]);
  ylabel(['Rel. quantization error, '])
  xlabel('Array element')
%  axis('normal');

%
% do not understand why this call is here? no such function exists
% SH 30.11.94

%%%%%%%%%  wrdelay(transducer,exact_rx,delta_t_rx,elem_pts,flagg);

end
