%
%------------------------------------------------------------------------
% Routine         : vwdepth.m       
%
% Description     : plotting of received spectrum as a function of depth
% Reference       : R. Kuc, Proc IEEE July 1985.
% Language        : Matlab syntax
% Written by      : Vingmed sound A/S, SH
% Date            : 24. September 1990 
% Version         : 2.0 
% Modified        : SH 18 May 1993 
%                   SH 19 Apr 2001  - initialized bw, warning for alfa=0, 
%                                     alfa input in Np/cm/MHz
% Called by       : none
% Routines called : none
% Load files      : none
%------------------------------------------------------------------------



function Y=vwdepth(excitation, media)
disp(' ')
disp(' *** vwdepth ***')
disp('View change in frequency spectrum with depth in a homogenous medium')
disp(' ')

spectype = input('Spectrum shape (0-Excitation pulse, 1-Gaussian, 2-sinc): ');
if isempty(spectype)
	spectype = 0;
end

f = excitation(1);
alfa =  media(1,9); % Np/cm/MHz
alfa = alfa/(10*log(10));% dB/cm/MHz
beta = media(1,10); % frequency dependency
if alfa == 0,
   disp('Warning: no change in spectrum with depth since attenuation is 0')
   disp('Set attenuation in medium menu')
end   
%
% set up sampling frequency
%

Fs=excitation(11);
intfact=excitation(12);  
if intfact==0
    tstep=1/Fs;
else
    tstep=1/(Fs*intfact);
end
Nfft = 1024;
%
% plot up to 4*center frequency
%
maxindex = 4*f*tstep*Nfft;
pick = 1:maxindex;
freq = (pick-1)/(tstep*Nfft);

bw = 0; % must be initalized
if spectype ~= 0;
      bw = input('-6 dB relative bandwidth (%): ')/100; 
end

if spectype == 2,
        sincconst = pi*1.21/(bw*f); 
        txspec = (sin(sincconst*(freq+eps-f))./(sincconst*(freq+eps-f))).^2;
elseif spectype == 1
        sigma = bw/(4*sqrt(log(2)));
	disp(['Standarddeviation: ',num2str(sigma*f*1e-6),' MHz'])
	disp(['  -3 dB bandwidth: ',num2str(bw*f/sqrt(2)*1e-6),' MHz'])
	disp(['  -6 dB bandwidth: ',num2str(bw*f*1e-6),' MHz'])
%
% rms bandwidth <=> exp(-1/2) = .606 = -2.17 dB
%
        txspec = exp(-(freq-f).^2/(2*(sigma*f).^2));

else    
%
% generate spectrum from menu input of pulse length and shape
%  
  
	osc=excitation(9);
 	pw=excitation(10);
	plen=osc/f;

	if finite(osc) & osc ~= 0
  		t=[0:tstep:plen];
  		s=sin(2*pi*f*t);
  		if pw==1
%
% cosine pulse
%
    			senv=sin(pi*t/plen);
    			s=senv.*s;
 		 end
%
% find spectrum of transmitted pulse
%
		S = fft(s,Nfft);
  		Sxx = abs((S(pick)));
		maxSxx = max(Sxx);
		txspec = (Sxx/maxSxx).^2;
	  
	else 
  		disp(['CW, frequency = ', num2str(f*1e-6),' MHz']);
		disp('Unable to plot spectrum!')
		return
	end
end

   txdB = 10*log10(txspec);
%
%  alfa is in dB/cm*MHz
%
%  dB/m*Hz
%
   alfanorm = alfa*1e2/1e6;
   depth = [0 .05 .1 .15 .2];
   depth2 = ones(size(freq'))*depth;
   freq2 = (1e6*((freq/1e6)').^beta) * ones(size(depth));
   transfer = -2*alfanorm*freq2.*depth2;
%
%  resulting received spectrum
%
   rxdB = txdB'*ones(size(depth)) + transfer;
%
%
   yf = [sprintf('%5.2f',f*1e-6),' MHz'];
   ybw = [sprintf('%5.2f',bw*100),' %'];
   ya = [sprintf('%5.2f',alfa),' dB/(cm*MHz)'];
   yd1 = sprintf('%5.1f,%5.1f,',depth(1)*100,depth(2)*100);
   yd2 = sprintf('%5.1f,%5.1f,',depth(3)*100,depth(4)*100);
   yd = [yd1,yd2,sprintf('%5.1f',depth(5)*100),' cm'];
   subplot(1,1,1)
   plot(freq', transfer,freq', rxdB,freq,-6*ones(size(freq)),':')
   datetext;
   title(['Two-way Transfer Functions, attenuation ',ya,...
          ', exp ',num2str(beta)]);

   if (spectype == 2),
      xlabel(['[MHz], sinc^2, center ',yf,', -6 dB bw ',ybw])
                elseif (spectype== 1)
      xlabel(['[MHz], Gaussian, center ',yf,', -6 dB bw ',ybw]);
   else
        xlabel(['[MHz], ',yf,', ',num2str(osc),' osc, ',weightxt(pw)])
   end
   ylabel(['[dB], depths:',yd]);
   grid
   if (beta >= 0),
      axis([0 2*f -100 0]);
   end 
  
